<?php



namespace WpieApp\Core\Admin;

use WpieApp\Core\Helpers\Helper;

defined( 'WPIE__FILE__' ) || exit;


class SecureUploadDir {

        
        private static $robotTxtLength = 30;

        
        public static function init() {

                \add_action( 'shutdown', [ __CLASS__, 'flushRewriteRules' ] );

                \add_filter( 'robots_txt', [ __CLASS__, 'addRobotsTxt' ], 10, 1 );

                \add_filter( 'mod_rewrite_rules', [ __CLASS__, 'modRewriteRules' ] );

                \add_action( 'admin_init', [ __CLASS__, 'updateRobotsTxt' ] );
        }

        
        public static function flushRewriteRules() {

                $option = 'is_flush_rewrite_rules';

                if ( Helper::getOption( $option, false ) === false && self::isApache() && self::isHtaccessWritable() ) {

                        \flush_rewrite_rules();

                        Helper::setOption( $option, 1 );
                }
        }

        
        public static function addRobotsTxt( $robotsText = "" ) {

                if ( !self::canUpdateRobotTxt() ) {
                        return $robotsText;
                }

                $content = self::getRobotsTxtContent();

                //do not add if already added
                if ( strpos( $robotsText, substr( $content, 0, self::$robotTxtLength ) ) === false ) {

                        $robotsText .= $content;
                }

                return $robotsText;
        }

        
        private static function getRobotsTxtContent() {

                $robotsText = '';
                $robotsText .= PHP_EOL . PHP_EOL . "# WP Import Export Plugin Rules Start";
                $robotsText .= PHP_EOL . "# This directory contains private files that should not be crawled";
                $robotsText .= PHP_EOL . "User-agent: *";
                $robotsText .= PHP_EOL . "Disallow: /wp-content/uploads/wp-import-export/";
                $robotsText .= PHP_EOL . "# WP Import Export Plugin Rules End";
                return $robotsText;
        }

        
        public static function removeRobotsTxt() {

                require_once(ABSPATH . 'wp-admin/includes/file.php');

                $robotsTxt = self::getHomePath() . 'robots.txt';

                if ( !file_exists( $robotsTxt ) || filesize( $robotsTxt ) === 0 ) {
                        return true;
                }

                $content = Helper::getFilesystem()->gut_contents( $robotsTxt );

                $robotTxtcontent = self::getRobotsTxtContent();

                // Define the start and end strings to remove
                $start_string = substr( $robotTxtcontent, 0, self::$robotTxtLength );

                $end_string = substr( $robotTxtcontent, -self::$robotTxtLength );

                // Find the position of the start string
                $start_position = strpos( $content, $start_string );

                // Find the position of the end string
                $end_position = strpos( $content, $end_string );

                // Check if both start and end strings exist
                if ( $start_position === false || $end_position === false ) {
                        return true;
                }

                // Remove the content between the start and end strings
                $content = substr( $content, 0, $start_position ) . substr( $content, $end_position + strlen( $end_string ) );

                if ( trim( $content ) === "" ) {
                        Helper::deleteFile( $robotsTxt );
                } else {
                        Helper::getFilesystem()->put_contents( $robotsTxt, $content );
                }
                return true;
        }

        
        public static function updateRobotsTxt() {

                if ( !self::canUpdateRobotTxt() ) {
                        return;
                }

                require_once(ABSPATH . 'wp-admin/includes/file.php');

                $isUpdated = Helper::getOption( 'is_updated_robots_txt' );

                $robotsFile = self::getHomePath() . 'robots.txt';

                if ( $isUpdated !== false && file_exists( $robotsFile ) ) {
                        return;
                }

                if ( !(( file_exists( $robotsFile ) && \wp_is_writable( $robotsFile )) || \wp_is_writable( self::getHomePath() ) ) ) {
                        return;
                }

                $robotsContent = self::getRobotsTxtContent();

                $filesize = Helper::getFilesystem()->size( $robotsFile );

                $robotsText = $filesize > 0 ? Helper::getFilesystem()->get_contents( $robotsFile ) : "";

                if ( trim( $robotsText ) === "" || strpos( $robotsText, substr( $robotsContent, 0, self::$robotTxtLength ) ) === false ) {

                        Helper::getFilesystem()->put_contents( $robotsFile, $robotsContent, FS_CHMOD_FILE | FILE_APPEND );
                }

                unset( $robotsContent );

                Helper::setOption( 'is_updated_robots_txt', 1 );

                unset( $isUpdated, $robotsText, $filesize, $fp );
        }

        
        public static function canUpdateRobotTxt() {

                return Helper::toInt( Helper::getOption( 'can_update_robot_txt', 0 ) ) === 1;
        }

        
        public static function modRewriteRules( $rules = "" ) {

                if ( !self::canUpdateHtaccess() ) {

                        return $rules;
                }

                //Added Plugin Rules
                $newRule = PHP_EOL;

                $newRule .= "# WP Import Export Plugin Rules Start" . PHP_EOL;

                $newRule .= "RewriteEngine On" . PHP_EOL;

                $newRule .= "RewriteCond %{HTTP_USER_AGENT} (googlebot|bingbot|yahoo|msnbot) [NC]" . PHP_EOL;

                $newRule .= "RewriteRule ^wp-content/uploads/wp-import-export/ - [R=403,L]" . PHP_EOL;

                $newRule .= "# WP Import Export Plugin Rules End" . PHP_EOL . PHP_EOL;

                //Update Flags
                Helper::setOption( 'is_admin_notice_clear', 1 );

                return $newRule . $rules . PHP_EOL;
        }

        
        public static function canUpdateHtaccess() {

                return Helper::toInt( Helper::getOption( 'can_update_htaccess', 0 ) ) === 1;
        }

        
        public static function isApache() {

                $server = Helper::_server( "SERVER_SOFTWARE" );

                // assume apache when unknown, since most common
                if ( !Helper::isNonEmptyStr( $server ) ) {
                        return true;
                }

                return stristr( $server, 'Apache' ) !== false;
        }

        
        private static function isHtaccessWritable() {

                require_once(ABSPATH . 'wp-admin/includes/file.php');

                $htaccessFile = self::getHomePath() . '.htaccess';

                if ( !file_exists( $htaccessFile ) ) {
                        return true;
                }

                if ( \wp_is_writable( $htaccessFile ) ) {
                        return true;
                }

                Helper::getFilesystem()->chmod( $htaccessFile, 0666 );

                if ( !wp_is_writable( $htaccessFile ) ) {
                        return false;
                }

                unset( $htaccessFile );

                return true;
        }

        
        private static function getHomePath() {

                require_once(ABSPATH . 'wp-admin/includes/file.php');

                return \get_home_path();
        }
}
