<?php



namespace WpieApp\Core\Admin;

use WpieApp\Core\Utils\DB;
use WpieApp\Core\Helpers\Helper;
use WpieApp\Modules\License\Controller\License;

defined( 'WPIE__FILE__' ) || exit;


class Uninstaller {

        
        public static function init() {

                \register_uninstall_hook( WPIE__FILE__, [ __CLASS__, 'uninstallAll' ] );
        }

        
        public static function uninstallAll() {

                if ( !defined( 'WP_UNINSTALL_PLUGIN' ) ) {
                        return;
                }

                if ( !is_multisite() ) {
                        self::uninstall();
                        return;
                }

                self::networkUninstall();
        }

        
        private static function networkUninstall() {

                $blog_ids = DB::wpdb()->get_col( "SELECT blog_id FROM " . DB::wpdb()->blogs . " WHERE archived = '0' AND spam = '0' AND deleted = '0'" );

                if ( Helper::isEmpty( $blog_ids ) ) {
                        return;
                }

                foreach ( $blog_ids as $blog_id ) {
                        \switch_to_blog( $blog_id );
                        self::uninstall();
                        \restore_current_blog();
                }
        }

        
        private static function uninstall() {

                License::deactivate();

                if ( 1 !== Helper::toInt( Helper::getOption( 'delete-on-uninstall', 0 ) ) ) {
                        return;
                }

                self::removeTables();

                self::removeDirectories();
        }

        
        private static function removeTables() {

                $tableName = DB::getPluginTable();

                //remove tables
                DB::wpdb()->query( "DROP TABLE IF EXISTS " . $tableName );

                //remove options
                DB::wpdb()->query( DB::wpdb()->prepare( 'DELETE FROM ' . DB::wpdb()->options . ' WHERE option_name LIKE %s', Helper::PLUGIN_PREFIX . '%' ) );
        }

        
        private static function removeDirectories() {

                Helper::getFilesystem()->rmdir( WPIE_UPLOAD_DIR, true );
        }
}
