<?php



namespace WpieApp\Core\Logger;

use Monolog\Logger as MonoLogger;
use Monolog\ErrorHandler;
use Monolog\Formatter\LineFormatter;
use Monolog\Handler\StreamHandler;
use Monolog\Handler\RotatingFileHandler;
use WpieApp\Core\Helpers\Helper;
use WpieApp\Core\Utils\Date;

defined( 'WPIE__FILE__' ) || exit;


class Logger {

        
        protected static $handle = null;

        
        const FORMAT = "[%datetime%] %level_name%: %message% %context% %extra%" . PHP_EOL . PHP_EOL;

        
        public static function register( $handle = '', $path = '', $level = MonoLogger::DEBUG, $isRotate = false ) {

                if ( Helper::isEmptyStr( $handle ) || Helper::isEmptyStr( $path ) ) {
                        return false;
                }
                $level = Helper::isEmptyStr( $level ) ? MonoLogger::DEBUG : $level;

                $formatter = new LineFormatter( self::FORMAT, Date::FORMAT, true, true );
                $formatter->includeStacktraces( true );

                $streamHandler = new StreamHandler( $path, $level );
                $streamHandler->setFormatter( $formatter );

                // create a log channel
                static::$handle = new MonoLogger( $handle );
                static::$handle->setTimezone( Date::getTimeZone() );
                static::$handle->pushHandler( $streamHandler );

                if ( $isRotate ) {

                        $handler = new RotatingFileHandler( $path, 30, $level, false, 0664 );
                        $handler->setFormatter( $formatter );
                        static::$handle->pushHandler( $handler );
                        unset( $handler );
                }

                ErrorHandler::register( static::$handle );

                unset( $formatter, $streamHandler );

                return static::$handle;
        }

        
        public static function log( $message, $context = [] ) {
                static::get()->info( $message, $context );
        }

        
        public static function info( $message, $context = [] ) {
                static::get()->info( $message, $context );
        }

        
        public static function notice( $message, $context = [] ) {
                static::get()->notice( $message, $context );
        }

        
        public static function warning( $message, $context = [] ) {
                static::get()->warning( $message, $context );
        }

        
        public static function error( $message, $context = [] ) {
                static::get()->error( $message, $context );
        }

        
        public static function critical( $message, $context = [] ) {
                static::get()->critical( $message, $context );
        }

        
        public static function alert( $message, $context = [] ) {
                static::get()->alert( $message, $context );
        }

        
        public static function get() {

                if ( static::$handle !== null ) {
                        return static::$handle;
                }

                return AutoLogger::get();
        }
}
