<?php

namespace WpieApp\Core\Office\Converter\Excel;

use WP_Error;
use WpieApp\Core\Helpers\Helper;
use WpieApp\Core\Resource\Resource;
use WpieApp\Core\Office\Writer\CSV\Writer;
use WpieApp\Core\Utils\OpenSpout;

defined( 'ABSPATH' ) || exit;

class Excel2Csv {

        
        public static function convert( $file = "", $dest = "", $options = [] ) {

                if ( !is_readable( $file ) ) {
                        /* translators: %s: File path */
                        return new WP_Error( 'wpieError', sprintf( __( "Fail to open File %s", 'wp-import-export' ), $file ) );
                }

                $format = Helper::getFileExt( $dest );

                if ( "csv" !== $format ) {
                        return new WP_Error( 'wpieError', __( "Invalid Destination Format", 'wp-import-export' ) );
                }

                //init Writer
                $writer = new Writer( );

                $isLoaded = $writer->load( $dest );

                if ( \is_wp_error( $isLoaded ) ) {
                        return new WP_Error( 'wpieError', __( "Invalid Destination Format", 'wp-import-export' ) );
                }

                $count = 0;

                $isCompleted = true;

                try {

                        $sheetName = isset( $options[ 'sheet' ] ) && Helper::isNonEmptyStr( $options[ 'sheet' ] ) ? $options[ 'sheet' ] : "";

                        $start = isset( $options[ 'start' ] ) ? Helper::toInt( $options[ 'start' ] ) : 0;

                        if ( $start === 0 ) {
                                
                        }

                        //init Reader
                        $reader = OpenSpout::getReader( $file );

                        if ( Resource::isExceeded( 85 ) ) {
                                return [ "status" => "fail" ];
                        }

                        // let's read the entire spreadsheet...
                        foreach ( $reader->getSheetIterator() as $sheetIndex => $sheet ) {

                                // Add sheets in the new file, as we read new sheets in the existing one
                                if ( Helper::isNonEmptyStr( $sheetName ) && $sheet->getName() !== $sheetName ) {
                                        continue;
                                }

                                foreach ( $sheet->getRowIterator() as $row ) {

                                        if ( Resource::isExceeded() ) {
                                                $isCompleted = false;
                                                break;
                                        }
                                        $count++;

                                        if ( $count < ($start + 1) ) {
                                                continue;
                                        }

                                        $writer->addRow( is_array( $row ) ? $row : $row->toArray() );
                                }

                                break;
                        }

                        $reader->close();

                        unset( $reader );
                } catch ( Exception $e ) {
                        return new WP_Error( 'wpieError', $e->getMessage() );
                }

                $writer->clear();

                unset( $writer );

                if ( !$isCompleted ) {
                        return [ "status" => "pending", 'start' => $count ];
                }

                return [ "status" => "completed" ];
        }
}
