<?php




namespace WpieApp\Core\Page\Blocks;

use WpieApp\Core\Helpers\Helper;

defined( 'WPIE__FILE__' ) || exit;


class Blocks {

	
	const DEFAULT_BLOCK = "Standard";

	
	private static $templates = [];

	
	private static function getTemplates() {

		if ( Helper::isNonEmptyArray( self::$templates ) ) {
			return self::$templates;
		}

		self::$templates = [];

		$findTemplatesClasses = glob( __DIR__ . '/Templates/*/Manager.php' );

		$templateDir = str_replace( '\\', '/', realpath( __DIR__ . '/Templates' ) );

		foreach ( $findTemplatesClasses as $templatesClasses ) {

			$templatesClasses = str_replace( '\\', '/', realpath( $templatesClasses ) );

			$getTemplateName = substr( $templatesClasses, strlen( rtrim( $templateDir, '/' ) ) + 1 );

			$getTemplateName = explode( '/', $getTemplateName );

			self::$templates[] = $getTemplateName[ 0 ];
		}

		return self::$templates;
	}

	
	private static function getTemplateClass( $name = "" ) {

		$templates = self::getTemplates();

		$name = Helper::isNonEmptyStr( $name ) ? Helper::sanitizeText( $name ) : self::DEFAULT_BLOCK;

		$position = array_search( $name, $templates );

		$template = $position === false ? "" : $templates[ $position ];

		if ( !Helper::isNonEmptyStr( $template ) ) {
			$template = self::DEFAULT_BLOCK;
		}

		return __NAMESPACE__ . "\\Templates\\{$template}\\Manager";
	}

	
	public static function render( $data = [] ) {

		if ( !Helper::isNonEmptyArray( $data ) ) {
			return;
		}

		$data = Helper::sortBy( $data );

		foreach ( $data as $block ) {

			$templateName = isset( $block[ 'template' ] ) ? $block[ 'template' ] : "";

			$template = self::getTemplateClass( $templateName );

			$template::render( $block );
		}
	}

}
