<?php


namespace WpieApp\Core\Page\Blocks\Fields;

use WpieApp\Core\Utils\License as LicenseManager;
use WpieApp\Core\Helpers\Helper;

defined( 'WPIE__FILE__' ) || exit;


class License {

        
        const TYPE = "license";

        
        public static function render( $field ) {

                $data = LicenseManager::getData();

                $license = Helper::isNonEmptyArray( $data ) && isset( $data[ 'license' ] ) ? $data[ 'license' ] : "";

                $expire = Helper::isNonEmptyArray( $data ) && isset( $data[ 'expire' ] ) ? $data[ 'expire' ] : "";

                $activeClass   = "";
                $inactiveClass = "";
                if ( Helper::isNonEmptyStr( $license ) && preg_match( '/^([a-f0-9]{8})-(([a-f0-9]{4})-){3}([a-f0-9]{12})$/i', $license ) === 1 ) {
                        $activeClass  = "d-none";
                        $purchaseCode = substr( $license, 0, 4 ) . "xxxx-xxxx-xxxx-xxxx-xxxx-xxxxxxxx" . substr( $license, -4 );
                } else {
                        $inactiveClass = "d-none";
                        $purchaseCode  = "";
                }

                $status      = __( 'Active', 'wp-import-export' );
                $statusClass = "text-success";
                $serviceIcon = "fa-check";
                $renewClass  = "d-none";

                if ( Helper::isNonEmptyStr( $expire ) && strtotime( $expire ) < strtotime( "today" ) ) {
                        $status      = __( 'Expired', 'wp-import-export' );
                        $statusClass = "text-danger bse-fw-600";
                        $renewClass  = "";
                        $serviceIcon = "fa-xmark fa-lg";
                }

                $pluiginUrl = "https://1.envato.market/1krom";

                $placeholder = "xxxxxxxx-xxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx";
                ?>
                <div class="wpie-license-wrapper">
                        <div class="wpie-license-active-wrapper <?php echo esc_attr( $activeClass ); ?>">
                                <div class="border rounded-1 p-3 bg-light ">
                                        <div class="wpie-field-description mb-3 bse-fs-14 text-secondary "><?php esc_html_e( 'A Purchase Code is required to access plugin updates, New Addons and support.', 'wp-import-export' ); ?> <a class="text-decoration-none bse-fw-600" href="<?php echo esc_url( "https://help.market.envato.com/hc/en-us/articles/202822600-Where-Is-My-Purchase-Code-" ); ?>" target="_blank"><?php esc_html_e( 'Click Here', 'wp-import-export' ); ?></a> <?php esc_html_e( 'For purchase code', 'wp-import-export' ); ?></div>
                                        <div class="wpie-field mb-2">
                                                <input type="text" class="form-control form-input wpie-purchase-code" placeholder="<?php echo esc_attr( $placeholder ); ?> ">
                                        </div>
                                </div>
                                <div class="wpie-field mt-4">
                                        <button type="button" class="btn wpie-license-activate-btn btn-primary"><i class="bse-fs-14 me-1 fa-solid fa-key"></i><?php esc_html_e( 'Activate', 'wp-import-export' ); ?></button>

                                </div>                      
                        </div>
                        <div class="wpie-license-inactive-wrapper <?php echo esc_attr( $inactiveClass ); ?>">
                                <div class="container border rounded-1 p-3 bg-light">
                                        <div class="row mb-3">
                                                <div class="col-3">
                                                        <?php esc_html_e( 'Purchase Code', 'wp-import-export' ); ?> 
                                                </div>
                                                <div class="col-auto text-success wpie-purchase-code-info">
                                                        <?php echo esc_html( $purchaseCode ); ?> 
                                                </div>
                                        </div>
                                        <div class="row mb-3">
                                                <div class="col-3">
                                                        <?php esc_html_e( 'Status', 'wp-import-export' ); ?> 
                                                </div>
                                                <div class="col-auto <?php echo esc_attr( $statusClass ); ?> wpie-license-info wpie-purchase-code-status-info">
                                                        <?php echo esc_html( $status ); ?> 
                                                </div>
                                        </div>
                                        <div class="row mb-3">
                                                <div class="col-3">
                                                        <?php esc_html_e( 'Support Until', 'wp-import-export' ); ?> 
                                                </div>
                                                <div class="col-auto wpie-purchase-code-expire-info wpie-license-info <?php echo esc_attr( $statusClass ); ?>">
                                                        <?php echo esc_html( $expire ); ?> 
                                                </div>
                                        </div>
                                        <div class="row ">
                                                <div class="col-3">
                                                        <?php esc_html_e( 'Services', 'wp-import-export' ); ?> 
                                                </div>
                                                <div class="col-auto">
                                                        <div class="border rounded-2 float-start me-3 px-2 py-1 bg-white m-auto wpie-license-info <?php echo esc_attr( $statusClass ); ?>"><i class="fa-solid me-2 wpie-license-info-icon <?php echo esc_attr( $serviceIcon ); ?>"></i><?php esc_html_e( 'New Addons', 'wp-import-export' ); ?> </div>
                                                        <div class="border rounded-2 float-start me-3 px-2 py-1 bg-white m-auto wpie-license-info <?php echo esc_attr( $statusClass ); ?>"><i class="fa-solid me-2 wpie-license-info-icon <?php echo esc_attr( $serviceIcon ); ?>"></i><?php esc_html_e( 'Support', 'wp-import-export' ); ?> </div>
                                                        <div class="border rounded-2 float-start me-3 px-2 py-1 bg-white m-auto text-success"><i class="fa-solid fa-check me-2"></i><?php esc_html_e( 'Updates', 'wp-import-export' ); ?> </div>                                                       

                                                </div>
                                        </div>
                                </div>
                                <div class="wpie-field mt-4">
                                        <button type="button" class="btn wpie-license-deactivate-btn btn-danger"><i class="bse-fs-14 me-1 fa-solid fa-ban"></i><?php esc_html_e( 'Deactivate', 'wp-import-export' ); ?></button>
                                        <a class="btn wpie-license-renew-btn btn-success ms-3 <?php echo esc_attr( $renewClass ); ?>" target="_blank" href="<?php echo esc_url( $pluiginUrl ); ?>"><i class="bse-fs-14 me-1 fa-solid fa-rotate"></i><?php esc_html_e( 'Renew Support', 'wp-import-export' ); ?></a>
                                </div>                      
                        </div>
                </div>



                <?php
        }

}
