<?php


namespace WpieApp\Core\Page\Blocks\Fields;

use WpieApp\Core\Helpers\Helper;
use WpieApp\Core\Utils\Cron;

defined( 'WPIE__FILE__' ) || exit;


class ScheduleSetup {

        
        const TYPE = "schedule-setup";

        
        public static function render( $field ) {

                $cronUrl     =  Cron::getUrl();
                ?>

                <div class="wpie-schedule-setup-wrapper">
                        <div class="container border rounded-1 p-3 bg-light">
                                <div class="bse-fw-600 bse-fs-16 border-bottom mb-3 pb-3"><?php esc_html_e( 'Adding the Cron Job', 'wp-import-export' ); ?></div>
                                <div class=" bse-fs-64 text-danger mb-3 border rounded-3 p-3 bg-danger border-danger bg-opacity-10"><?php esc_html_e( 'One time setup only', 'wp-import-export' ); ?></div>
                                <div class="bse-fs-14 mb-3"><?php esc_html_e( "The instructions for setting up cron jobs may differ depending on the hosting provider or control panel you are using. However, one common method involves using the wget command to execute the cron URLs. Here's an example of how you can set up a cron job using wget:", 'wp-import-export' ); ?></div>
                                <div class="bse-fs-14 mb-3 border p-3 bg-success bg-opacity-10 text-dark rounded-3">
                                        <ol class="m-0 ">
                                                <li class="ps-2"><?php esc_html_e( "Log in to your web hosting control panel.", 'wp-import-export' ); ?></li>
                                                <li class="ps-2"><?php esc_html_e( 'Look for the section or option related to cron jobs. This may be called "Cron Jobs", "Scheduled Tasks" or something similar.', 'wp-import-export' ); ?></li>
                                                <li class="ps-2"><?php esc_html_e( 'Click on the option to create a new cron job.', 'wp-import-export' ); ?></li>
                                                <li class="ps-2"><?php esc_html_e( 'Specify the timing and frequency at which you want the cron job to run. This is typically done using the cron syntax, which consists of five fields representing the minute, hour, day of the month, month, and day of the week.', 'wp-import-export' ); ?></li>
                                                <li class="ps-2"><?php esc_html_e( 'In the command field, enter the wget command followed by the URL you want to hit. see below Adding the commands', 'wp-import-export' ); ?></li>
                                                <li class="ps-2"><?php esc_html_e( 'Save or submit the cron job. The cron job will now run at the specified intervals, executing the `wget` command and hitting the provided URL.', 'wp-import-export' ); ?></li>
                                        </ol>
                                </div>
                                <div class="bse-fw-600 bse-fs-16 border-bottom mb-3 pb-3 my-5"><?php esc_html_e( 'Adding the commands', 'wp-import-export' ); ?></div>
                                <div class="bse-fs-14 mb-3"><?php esc_html_e( 'Cronjob with the following structure:', 'wp-import-export' ); ?></div>
                                <div class="bse-fs-14 mb-3 border p-3 bg-success bg-opacity-10 text-dark rounded-3"><?php echo esc_html( "*/2 * * * * command" ); ?></div>
                                <div class="bse-fs-14 mb-3"><?php echo esc_html__( 'Replace', 'wp-import-export' ) . ' <span class="text-primary">command</span> ' . esc_html__( 'with one of the following options based on your preference:', 'wp-import-export'  ); ?></div>
                                <div class="bse-fs-14 mb-2 bse-fw-600 mt-5"><?php esc_html_e( 'Option 1 : Using wget', 'wp-import-export' ); ?></div>
                                <div class="bse-fs-14 mb-3 border p-3 bg-success bg-opacity-10 text-dark rounded-3"><?php echo esc_html( "wget -q -O /dev/null " . $cronUrl ); ?></div>
                                <div class="bse-fs-14 mb-2 bse-fw-600 mt-5"><?php esc_html_e( 'Option 2 : Using curl with output redirection', 'wp-import-export' ); ?></div>
                                <div class="bse-fs-14 mb-3 border p-3 bg-success bg-opacity-10 text-dark rounded-3"><?php echo esc_html( "curl -sS " . $cronUrl . " > /dev/null" ); ?></div>
                                <div class="bse-fs-14 mb-2 bse-fw-600 mt-5"><?php esc_html_e( 'Option 3 : Using Lynx', 'wp-import-export' ); ?></div>
                                <div class="bse-fs-14 mb-3 border p-3 bg-success bg-opacity-10 text-dark rounded-3"><?php echo esc_html( "lynx -dump " . $cronUrl . " > /dev/null" ); ?></div>
                                <div class="bse-fs-14 mb-2 bse-fw-600 mt-5"><?php esc_html_e( 'Option 4 : Using cURL with silent mode and output redirection', 'wp-import-export' ); ?></div>
                                <div class="bse-fs-14 mb-3 border p-3 bg-success bg-opacity-10 text-dark rounded-3"><?php echo esc_html( "curl -sS " . $cronUrl . " 2>&1 >/dev/null" ); ?></div>
                                <div class="bse-fs-14 mb-2 bse-fw-600 mt-5"><?php esc_html_e( 'Option 5 : Using email to hosting support (Sample email)', 'wp-import-export' ); ?></div>
                                <div class="bse-fs-14 mb-3 border p-3 bg-success bg-opacity-10 text-dark rounded-3">
                                        <div class="bse-fs-14 mb-5"><?php echo esc_html( 'Subject : Request to Set Up Cron Job on My Website' ); ?></div>
                                        <div class="bse-fs-14 mb-3"><?php echo esc_html( "Dear [Hosting Provider's Support Team]," ); ?></div>
                                        <div class="bse-fs-14 mb-3"><?php echo esc_html( "I hope this email finds you well. I am writing to request your assistance in setting up a cron job on my website. I need to automate the regular access of a specific URL to perform certain tasks." ); ?></div>
                                        <div class="bse-fs-14 mb-3"><?php echo esc_html( "Here are the details of the cron job I would like to set up:" ); ?></div>
                                        <div class="bse-fs-14 mb-3"><?php echo esc_html( "Interval : Every 2 minutes" ); ?></div>
                                        <div class="bse-fs-14 mb-3"><?php echo esc_html( "URL : " . $cronUrl ); ?></div>
                                        <div class="bse-fs-14 mb-3"><?php echo esc_html( "Thank you very much for your prompt attention to this matter. I look forward to your assistance." ); ?></div>
                                        <div class="bse-fs-14 mb-3"><?php echo esc_html( "Best regards," ); ?></div>
                                        <div class="bse-fs-14 mb-3"><?php echo esc_html( "[Your Name]" ); ?></div>
                                        <div class="bse-fs-14 mb-3"><?php echo esc_html( "[Your Website]" ); ?></div>
                                        <div class="bse-fs-14 mb-3"><?php echo esc_html( "[Your Contact Information]" ); ?></div>
                                </div>
                        </div>

                </div>



                <?php
        }

}
