<?php



namespace WpieApp\Extensions\Export\AllInOneSeo\Controller\Items\Taxonomy\Fields;

use WpieApp\Modules\Export\Controller\Settings;
use WpieApp\Modules\Export\Controller\Items\Base\Fields\InterfaceField;
use WpieApp\Modules\Export\Controller\Items\Taxonomy\Fields\Meta as PostMeta;

defined( 'WPIE__FILE__' ) || exit;


class Seo implements InterfaceField {

        
        const FIELD_TYPE = "all-in-one-seo";

        
        public static function get() {

                $fields = [
                        "title"      => \esc_html__( "All In One SEO", 'wp-import-export' ),
                        "priority"   => 28,
                        "isFiltered" => false,
                        "pro"        => true,
                        "data"       => [
                                //General
                                [ 'label' => 'SEO Title', 'type' => PostMeta::FIELD_TYPE, 'element' => '_aioseo_title' ],
                                [ 'label' => 'SEO Meta Description', 'type' => PostMeta::FIELD_TYPE, 'element' => '_aioseo_description' ],
                                [ 'label' => 'SEO Score', 'type' => self::FIELD_TYPE, 'element' => 'seo_score' ],
                                //Facebook
                                [ 'label' => 'SEO Facebook Title', 'type' => PostMeta::FIELD_TYPE, 'element' => '_aioseo_og_title' ],
                                [ 'label' => 'SEO Facebook Description', 'type' => PostMeta::FIELD_TYPE, 'element' => '_aioseo_og_description' ],
                                [ 'label' => 'SEO Facebook Image Source', 'type' => self::FIELD_TYPE, 'element' => 'og_image_type' ],
                                [ 'label' => 'SEO Facebook Image Custom Field Name', 'type' => self::FIELD_TYPE, 'element' => 'og_image_custom_fields' ],
                                [ 'label' => 'SEO Facebook Image Custom URL', 'type' => self::FIELD_TYPE, 'element' => 'og_image_custom_url' ],
                                [ 'label' => 'SEO Facebook Video', 'type' => self::FIELD_TYPE, 'element' => 'og_video' ],
                                [ 'label' => 'SEO Facebook Object Type', 'type' => self::FIELD_TYPE, 'element' => 'og_object_type' ],
                                [ 'label' => 'SEO Facebook Article Section', 'type' => PostMeta::FIELD_TYPE, 'element' => '_aioseo_og_article_section' ],
                                [ 'label' => 'SEO Facebook Article Tags', 'type' => PostMeta::FIELD_TYPE, 'element' => '_aioseo_og_article_tags' ],
                                //Twitter
                                [ 'label' => 'SEO Twitter Use Data from Facebook Tab', 'type' => self::FIELD_TYPE, 'element' => 'twitter_use_og' ],
                                [ 'label' => 'SEO Twitter Title', 'type' => PostMeta::FIELD_TYPE, 'element' => '_aioseo_twitter_title' ],
                                [ 'label' => 'SEO Twitter Description', 'type' => PostMeta::FIELD_TYPE, 'element' => '_aioseo_twitter_description' ],
                                [ 'label' => 'SEO Twitter Image Source', 'type' => self::FIELD_TYPE, 'element' => 'twitter_image_type' ],
                                [ 'label' => 'SEO Twitter Image Custom URL', 'type' => self::FIELD_TYPE, 'element' => 'twitter_image_custom_url' ],
                                [ 'label' => 'SEO Twitter Image Custom Fields', 'type' => self::FIELD_TYPE, 'element' => 'twitter_image_custom_fields' ],
                                [ 'label' => 'SEO Twitter Card Type', 'type' => self::FIELD_TYPE, 'element' => 'twitter_card' ],
                                // Robots Meta
                                [ 'label' => 'SEO Robots Default', 'type' => self::FIELD_TYPE, 'element' => 'robots_default' ],
                                [ 'label' => 'SEO Robots No Index', 'type' => self::FIELD_TYPE, 'element' => 'robots_noindex' ],
                                [ 'label' => 'SEO Robots No Follow', 'type' => self::FIELD_TYPE, 'element' => 'robots_nofollow' ],
                                [ 'label' => 'SEO Robots No Archive', 'type' => self::FIELD_TYPE, 'element' => 'robots_noarchive' ],
                                [ 'label' => 'SEO Robots No Translate', 'type' => self::FIELD_TYPE, 'element' => 'robots_notranslate' ],
                                [ 'label' => 'SEO Robots No Image Index', 'type' => self::FIELD_TYPE, 'element' => 'robots_noimageindex' ],
                                [ 'label' => 'SEO Robots No Snippet', 'type' => self::FIELD_TYPE, 'element' => 'robots_nosnippet' ],
                                [ 'label' => 'SEO Robots No ODP', 'type' => self::FIELD_TYPE, 'element' => 'robots_noodp' ],
                                [ 'label' => 'SEO Robots No Max Snippet', 'type' => self::FIELD_TYPE, 'element' => 'robots_max_snippet' ],
                                [ 'label' => 'SEO Robots Max Video Preview', 'type' => self::FIELD_TYPE, 'element' => 'robots_max_videopreview' ],
                                [ 'label' => 'SEO Robots Max Image Preview', 'type' => self::FIELD_TYPE, 'element' => 'robots_max_imagepreview' ],
                                //advance
                                [ 'label' => 'SEO Canonical URL', 'type' => self::FIELD_TYPE, 'element' => 'canonical_url' ],
                                [ 'label' => 'SEO Priority', 'type' => self::FIELD_TYPE, 'element' => 'priority' ],
                                [ 'label' => 'SEO Frequency', 'type' => self::FIELD_TYPE, 'element' => 'frequency' ],
                                [ 'label' => 'SEO Keywords', 'type' => self::FIELD_TYPE, 'element' => 'keywords' ],
                        ]
                ];

                
                return \apply_filters( 'Wpie/Export/Taxonomy/Fields/AllInOneSeo', $fields, Settings::getContentType() );
        }
}
