<?php



namespace WpieApp\Extensions\Export\YoastSeo\Controller;

use WPSEO_Post_Type;
use WpieApp\Modules\Export\Helpers\Helper;
use WpieApp\Modules\Export\Controller\Settings;
use WpieApp\Extensions\Export\YoastSeo\Controller\Items\Post\Manager as Post;
use WpieApp\Extensions\Export\YoastSeo\Controller\Items\Taxonomy\Manager as Taxonomy;
use WpieApp\Extensions\Export\YoastSeo\Controller\Items\User\Manager as User;

defined( 'WPIE__FILE__' ) || exit;


class Manager {

        
        public static function init() {

                \add_action( 'Wpie/Export/Post/Init', [ __CLASS__, 'initPost' ], 1, 2 );
                \add_action( 'Wpie/Export/Taxonomy/Init', [ __CLASS__, 'initTaxonomy' ], 1, 2 );
                \add_action( 'Wpie/Export/User/Init', [ __CLASS__, 'initUser' ], 1, 2 );
        }

        
        public static function initPost( $contentType = '', $category = '' ) {

                if ( !WPSEO_Post_Type::is_post_type_accessible( $contentType ) || !WPSEO_Post_Type::is_post_type_indexable( $contentType ) ) {
                        return;
                }

                Post::init();
        }

        
        public static function initTaxonomy( $contentType = '', $category = '' ) {

                $allowedTaxonomies = YoastSEO()->helpers->taxonomy->get_public_taxonomies();

                $isIndexable = YoastSEO()->helpers->taxonomy->is_indexable( $contentType );

                if ( (is_array( $contentType ) && !Helper::isNonEmptyArray( array_intersect( $allowedTaxonomies, $contentType ) )) || (is_string( $contentType ) && !isset( $allowedTaxonomies[ $contentType ] )) || !$isIndexable ) {
                        return;
                }

                Taxonomy::init();
        }

        
        public static function initUser( $contentType = '', $category = '' ) {

                User::init();
        }

}
