<?php



namespace WpieApp\Extensions\Import\AllInOneSeo\Controller\Items\Base\Engines;

use WpieApp\Modules\Import\Helpers\Helper;
use WpieApp\Modules\Import\Controller\Items\Post\DataCenter;
use WpieApp\Extensions\Import\AllInOneSeo\Controller\Items\Base\Fields\Facebook\ImageType;
use WpieApp\Extensions\Import\AllInOneSeo\Controller\Items\Base\Fields\Facebook\ObjectType;

defined( 'WPIE__FILE__' ) || exit;


class Facebook {

        
        public static function get() {

                $data = [];

                if ( DataCenter::canUpdate( 'allinoneseo/facebook/title' ) ) {
                        $data[ "og_title" ] = DataCenter::get( "allinoneseo/facebook/title/data" );
                }

                if ( DataCenter::canUpdate( 'allinoneseo/facebook/description' ) ) {
                        $data[ "og_description" ] = DataCenter::get( "allinoneseo/facebook/description/data" );
                }

                if ( DataCenter::canUpdate( 'allinoneseo/facebook/image_type' ) ) {

                        $type = DataCenter::get( "allinoneseo/facebook/image_type/data" );

                        $data[ "og_image_type" ] = Helper::autoFixStr( $type, array_keys( ImageType::getSource() ), false );

                        $data[ "og_image_custom_fields" ] = DataCenter::get( "allinoneseo/facebook/image_custom_fields/data" );

                        $data[ "og_image_custom_url" ] = DataCenter::get( "allinoneseo/facebook/image_custom_url/data" );
                }

                if ( DataCenter::canUpdate( 'allinoneseo/facebook/video' ) ) {
                        $data[ "og_video" ] = DataCenter::get( "allinoneseo/facebook/video/data" );
                }

                if ( DataCenter::canUpdate( 'allinoneseo/facebook/object_type' ) ) {

                        $type = DataCenter::get( "allinoneseo/facebook/object_type/data" );

                        $data[ "og_object_type" ] = Helper::autoFixStr( $type, ObjectType::getObjectType() );
                }

                if ( DataCenter::canUpdate( 'allinoneseo/facebook/article_section' ) ) {
                        $data[ "og_article_section" ] = DataCenter::get( "allinoneseo/facebook/article_section/data" );
                }

                if ( DataCenter::canUpdate( 'allinoneseo/facebook/article_tags' ) ) {

                        $data[ "og_article_tags" ] = self::getArticleTags();
                }

                return $data;
        }

        
        public static function getArticleTags() {

                $separator = DataCenter::get( "allinoneseo/facebook/article_tags/separator" );

                $separator = Helper::isNonEmptyStr( $separator ) ? $separator : ",";

                $tags = Helper::strToArr( DataCenter::get( "allinoneseo/facebook/article_tags/data" ), $separator );

                if ( !Helper::isNonEmptyArray( $tags ) ) {
                        return '';
                }

                $data = [];

                foreach ( $tags as $tag ) {

                        $data[] = [ "label" => $tag, "value" => $tag ];
                }

                return Helper::jsonEncode( $data );
        }
}
