<?php



namespace WpieApp\Extensions\Import\WooCommerce\Controller\Items\Coupon\Engines;

use WpieApp\Modules\Import\Helpers\Helper;
use WpieApp\Modules\Import\Controller\Settings;
use WpieApp\Modules\Import\Controller\Items\Post\DataCenter;
use WpieApp\Modules\Import\Controller\Items\Post\Search;
use WpieApp\Modules\Import\Controller\Items\Term\Search as TermSearch;

defined( 'WPIE__FILE__' ) || exit;


class UsageRestriction {

        
        public static function update() {


                if ( DataCenter::canUpdate( 'restriction/minimum_amount' ) ) {

                        $minimumAmount = DataCenter::get( "restriction/minimum_amount/data" );

                        Meta::update( 'minimum_amount', Helper::toNumber( $minimumAmount ) );
                }
                if ( DataCenter::canUpdate( 'restriction/maximum_amount' ) ) {

                        $maximumAmount = DataCenter::get( "restriction/maximum_amount/data" );

                        Meta::update( 'maximum_amount', Helper::toNumber( $maximumAmount ) );
                }
                if ( DataCenter::canUpdate( 'restriction/individual_use' ) ) {

                        $individualUse = DataCenter::get( "restriction/individual_use/data" );

                        Meta::update( 'individual_use', Helper::detectBoolVal( $individualUse ) === true ? 'yes' : 'no'  );
                }
                if ( DataCenter::canUpdate( 'restriction/exclude_sale_items' ) ) {

                        $excludeSaleItems = DataCenter::get( "restriction/exclude_sale_items/data" );

                        Meta::update( 'exclude_sale_items', Helper::detectBoolVal( $excludeSaleItems ) === true ? 'yes' : 'no'  );
                }
                if ( DataCenter::canUpdate( 'restriction/products' ) ) {

                        $products = DataCenter::get( "restriction/products/data" );

                        $separator = DataCenter::get( "restriction/products/separator" );

                        $separator = Helper::isNonEmptyStr( $separator ) ? $separator : '||';

                        Meta::update( 'product_ids', self::getProducts( $products, $separator ) );
                }
                if ( DataCenter::canUpdate( 'restriction/exclude_products' ) ) {

                        $excludeProducts = DataCenter::get( "restriction/exclude_products/data" );

                        $separator = DataCenter::get( "restriction/exclude_products/separator" );

                        $separator = Helper::isNonEmptyStr( $separator ) ? $separator : '||';

                        Meta::update( 'exclude_product_ids', self::getProducts( $excludeProducts, $separator ) );
                }
                if ( DataCenter::canUpdate( 'restriction/product_categories' ) ) {

                        $categories = DataCenter::get( "restriction/product_categories/data" );

                        $separator = DataCenter::get( "restriction/product_categories/separator" );

                        $separator = Helper::isNonEmptyStr( $separator ) ? $separator : '||';

                        Meta::updateMeta( 'product_categories', self::getCategories( $categories, $separator ) );
                }
                if ( DataCenter::canUpdate( 'restriction/exclude_product_categories' ) ) {

                        $excludeCategories = DataCenter::get( "restriction/exclude_product_categories/data" );

                        $separator = DataCenter::get( "restriction/exclude_product_categories/separator" );

                        $separator = Helper::isNonEmptyStr( $separator ) ? $separator : '||';

                        Meta::updateMeta( 'exclude_product_categories', self::getCategories( $excludeCategories, $separator ) );
                }
                if ( DataCenter::canUpdate( 'restriction/customer_email' ) ) {

                        $customerEmail = DataCenter::get( "restriction/customer_email/data" );

                        Meta::updateMeta( 'customer_email', self::getEmails( $customerEmail ) );
                }
        }

        
        public static function getProducts( $data = '', $separator = '||' ) {

                if ( !Helper::isNonEmptyStr( $data ) ) {
                        return '';
                }

                $products = Helper::strToArr( $data, $separator );

                $postType = [ 'product', 'product_variation' ];

                $ids = [];

                foreach ( $products as $product ) {

                        $id = Search::getPostIdByMeta( '_sku', $product, $postType );

                        if ( 1 > $id ) {

                                $options = [
                                        [ "args" => [
                                                        [ "key" => 'name', "value" => $product, 'relation' => 'or' ],
                                                        [ "key" => 'title', "value" => $product, 'relation' => 'or' ],
                                                        [ "key" => 'content', "value" => $product, 'relation' => 'or' ],
                                                ]
                                        ],
                                        [ "args" => [
                                                        [ "key" => "type", "value" => $postType ]
                                                ]
                                        ]
                                ];

                                $id = Search::getId( $options );
                        }

                        if ( 1 > $id ) {
                                continue;
                        }

                        $ids[] = $id;
                }

                return Helper::isNonEmptyArray( $ids ) ? Helper::arrTostr( $ids ) : '';
        }

        
        public static function getCategories( $data = '', $separator = '||' ) {

                if ( !Helper::isNonEmptyStr( $data ) ) {
                        return '';
                }

                $categories = Helper::strToArr( $data, $separator );

                $taxonomy = 'product_cat';

                $ids = [];

                foreach ( $categories as $category ) {


                        $id = TermSearch::getTermIdBy( 'slug', $category, $taxonomy );

                        if ( 1 > $id ) {

                                $id = TermSearch::getTermIdBy( 'name', $category, $taxonomy );
                        }

                        if ( 1 > $id ) {
                                continue;
                        }

                        $ids[] = $id;
                }

                return Helper::isNonEmptyArray( $ids ) ? $ids : '';
        }

        
        public static function getEmails( $data = '' ) {

                if ( !Helper::isNonEmptyStr( $data ) ) {
                        return '';
                }

                $emails = Helper::strToArr( $data );

                $emailsList = [];

                foreach ( $emails as $email ) {

                        $email = \trim( $email );

                        // Use filter_var to check basic email format
                        if ( !Helper::isEmail( $email ) ) {
                                continue;
                        }

                        $emailsList[] = $email;
                }

                return $emailsList;
        }

}
