<?php



namespace WpieApp\Extensions\Import\WooCommerce\Controller\Items\Product\Fields\General;

use WC_Tax;
use WpieApp\Modules\Import\Helpers\Helper;
use WpieApp\Modules\Import\Controller\Settings;

defined( 'WPIE__FILE__' ) || exit;


class TaxClass {

        
        public static function getBlocks() {

                return [
                        "title"  => __( 'Tax Class', 'wp-import-export' ),
                        "desc"   => __( 'Tax Class', 'wp-import-export' ),
                        "order"  => 20,
                        "fields" => [
                                "tax-class" => [
                                        "order"      => 10,
                                        "label"      => __( 'Tax Class', 'wp-import-export' ),
                                        "sub-fields" => [
                                                "tax-class" => [
                                                        "description"   => __( 'Tax Class', 'wp-import-export' ),
                                                        "name"          => "fields/general/tax-class/data",
                                                        "type"          => "radio",
                                                        "default"       => "",
                                                        "choices"       => self::getTaxClasses(),
                                                        "hints"         => [
                                                                "as_specified" => __( 'Custom Option specified by you', 'wp-import-export' ),
                                                        ],
                                                        "choices-class" => [
                                                                ""             => "bse-form-check-success",
                                                                "as_specified" => "bse-form-check-primary"
                                                        ],
                                                        "fields"        => [
                                                                "as_specified" => [
                                                                        "tax-class-as-specified" => [
                                                                                "order"      => 5,
                                                                                "sub-fields" => [
                                                                                        "as-specified" => [
                                                                                                "description" => __( 'All Above Option are supported', 'wp-import-export' ),
                                                                                                "name"        => "fields/general/tax-class/data_as_specified",
                                                                                                "class"       => "",
                                                                                                "order"       => 10,
                                                                                                "type"        => "textarea",
                                                                                        ]
                                                                                ]
                                                                        ]
                                                                ]
                                                        ],
                                                ]
                                        ],
                                ],
                        ]
                ];
        }

        
        public static function getTaxClasses() {

                if ( !method_exists( '\WC_Tax', 'get_tax_rate_classes' ) ) {
                        return self::getTaxClassesDeprecated();
                }

                $taxClasses = WC_Tax::get_tax_rate_classes();

                $data = [
                        '' => __( 'Standard', 'wp-import-export' )
                ];

                if ( !Helper::isNonEmptyArray( $taxClasses ) ) {
                        $data[ "as_specified" ] = __( "As specified", 'wp-import-export' );
                        return $data;
                }

                foreach ( $taxClasses as $taxClass ) {

                        $slug = isset( $taxClass->slug ) ? $taxClass->slug : '';

                        $data[ $slug ] = isset( $taxClass->name ) ? $taxClass->name : '';
                }

                $data[ "as_specified" ] = __( "As specified", 'wp-import-export' );

                return $data;
        }

        
        public static function getTaxClassesDeprecated() {

                $taxClasses = WC_Tax::get_tax_classes();

                $data = [
                        '' => __( 'Standard', 'wp-import-export' )
                ];

                if ( !Helper::isNonEmptyArray( $taxClasses ) ) {
                        $data[ "as_specified" ] = __( "As specified", 'wp-import-export' );
                        return $data;
                }

                foreach ( $taxClasses as $taxClass ) {

                        $slug = \sanitize_title( $taxClass );

                        $data[ $slug ] = $taxClass;
                }

                $data[ "as_specified" ] = __( "As specified", 'wp-import-export' );

                return $data;
        }
}
