<?php



namespace WpieApp\Extensions\Import\Wpml\Controller\Items\Attribute;

use WpieApp\Modules\Import\Helpers\Helper;
use WpieApp\Modules\Import\Controller\Items\Term\Settings;
use WpieApp\Modules\Import\Controller\Items\Base\DataCenter;

defined( 'WPIE__FILE__' ) || exit;


class Engine {

        
        protected static $attributes;

        
        public static function isAttribute() {

                if ( 'wc' !== Settings::get( 'category' ) || 'attribute' !== Settings::get( 'content_type' ) ) {
                        return false;
                }

                return true;
        }

        
        public static function isTranslatable() {

                global $woocommerce_wpml;

                if ( !$woocommerce_wpml || !isset( $woocommerce_wpml->settings ) ) {
                        return false;
                }

                if ( !defined( 'WPML_ST_VERSION' ) ) {
                        return false;
                }

                return true;
        }

        
        public static function updateTranslatable() {

                if ( !self::isAttribute() || !self::isTranslatable() ) {
                        return false;
                }

                $attribute = DataCenter::getItem()->taxonomy;

                if ( isset( self::$attributes[ $attribute ] ) ) {
                        return self::$attributes[ $attribute ];
                }

                $translatable = DataCenter::get( "wpml/is-translatable/data" );

                if ( !DataCenter::canUpdate( "wpml/is-translatable" ) || '' === trim( $translatable ) ) {
                        return self::getTranslatable( $attribute );
                }

                $isTranslatable = Helper::detectBoolVal( $translatable ) !== false ? 1 : 0;

                self::$attributes[ $attribute ] = self::update( $attribute, $isTranslatable );

                return self::$attributes[ $attribute ];
        }

        
        public static function update( $attribute, $isTranslatable = 0 ) {

                global $woocommerce_wpml;

                if ( !isset( $woocommerce_wpml->attributes ) ) {
                        return false;
                }
                if ( !is_callable( [ $woocommerce_wpml->attributes, 'set_attribute_config_in_settings' ] ) ) {
                        return false;
                }

                $woocommerce_wpml->attributes->set_attribute_config_in_settings( $attribute, $isTranslatable );

                return $isTranslatable === 1;
        }

        
        public static function getTranslatable( $attribute ) {

                global $woocommerce_wpml;

                if ( !isset( $woocommerce_wpml->attributes ) ) {
                        return false;
                }
                if ( !is_callable( [ $woocommerce_wpml->attributes, 'is_translatable_attribute' ] ) ) {
                        return false;
                }

                $translatable = $woocommerce_wpml->attributes->is_translatable_attribute( $attribute );

                return ( is_numeric( $translatable ) && absint( $translatable ) === 1);
        }
}
