<?php



namespace WpieApp\Modules\Base\Controller;

use WpieApp\Core\Utils\Date;
use WpieApp\Core\Helpers\Helper;
use WpieApp\Modules\Base\Model\Settings as Model;

defined( 'WPIE__FILE__' ) || exit;


class Settings extends Model {

        
        public static function load( $data = null ) {

                if ( is_numeric( $data ) && intval( $data ) > 0 ) {

                        $data = Helper::toInt( $data );

                        $id = static::get( "id" );

                        if ( $id > 0 && $data === $id ) {
                                return;
                        }

                        $data = static::getSettingById( intval( $data ) );
                }

                if ( !Helper::isNonEmptyArray( $data ) ) {
                        $data = [];
                }

                static::$data = array_replace( static::getDefaults(), static::getData( $data ) );
        }

        
        private static function getDefaults() {

                $current_time = Date::now();

                return [
                        "id"                    => 0,
                        "uid"                   => Helper::randStr(),
                        "status"                => "draft",
                        "content_type"          => "",
                        "category"              => "",
                        "process"               => "import",
                        "process_type"          => "regular",
                        "options"               => [],
                        "log"                   => [],
                        "total"                 => 0,
                        "records_per_iteration" => 0,
                        "name"                  => "",
                        "filedir"               => Helper::randStr(),
                        //"filename"		 => "",
                        "file"                  => "",
                        "user"                  => Helper::getCurrentUserEmail(),
                        "parent"                => 0,
                        "is_locked"             => 0,
                        "created_date"          => $current_time,
                        "updated_date"          => $current_time,
                ];
        }

        
        protected static function getData( $data = null ) {

                $newData = [];

                if ( !Helper::isNonEmptyArray( $data ) ) {
                        return $newData;
                }

                foreach ( $data as $key => $val ) {

                        switch ( $key ) {
                                case "status":
                                case "content_type":
                                case "category":
                                case "process":
                                case "process_type":
                                        $newData[ $key ] = Helper::sanitizeKey( $val );
                                        break;
                                case "uid":
                                case "name":
                                //	case "filename":
                                case "file":
                                case "filedir":
                                case "user":
                                        $newData[ $key ] = Helper::sanitizeText( $val );
                                        break;
                                case "id":
                                case "total":
                                case "parent":
                                case "is_locked":
                                case "records_per_iteration":
                                        $newData[ $key ] = Helper::toInt( $val );
                                        break;
                                case "options":
                                case "log":
                                        if ( Helper::isNonEmptyStr( $val ) ) {
                                                $val = \maybe_unserialize( $val );
                                        }
                                        $newData[ $key ] = Helper::isNonEmptyArray( $val ) ? $val : [];

                                        break;
                        }
                }

                return $newData;
        }

        
        public static function getOption( $option = "", $default = "" ) {

                if ( Helper::isEmptyStr( $option ) ) {
                        return $default;
                }

                $parts = Helper::strToArr( $option, '/' );

                $data = isset( static::$data[ 'options' ] ) ? static::$data[ 'options' ] : [];

                foreach ( $parts as $part ) {

                        if ( isset( $data[ $part ] ) ) {
                                $data = $data[ $part ];
                        } else {
                                $data = null;
                                break;
                        }
                }

                $data = Helper::isEmpty( $data ) ? $default : $data;

                
                return \apply_filters( 'Wpie/Settings/Options', $data, $option );
        }

        
        public static function getContentType() {

                
                return \apply_filters( 'Wpie/Settings/ContentType', static::get( 'content_type' ) );
        }

        
        public static function get( $option = "", $default = "" ) {

                if ( Helper::isEmptyStr( $option ) ) {
                        return $default;
                }

                $data = null;

                if ( isset( static::$data[ $option ] ) ) {
                        $data = static::$data[ $option ];
                }

                $data = Helper::isEmpty( $data ) ? $default : $data;

                
                return \apply_filters( 'Wpie/Settings', $data, $option );
        }

        
        public static function set( $options = "", $value = "" ) {

                if ( Helper::isNonEmptyStr( $options ) ) {
                        $options = [ $options => $value ];
                }

                if ( !Helper::isNonEmptyArray( $options ) ) {
                        return false;
                }

                foreach ( $options as $key => $val ) {

                        if ( !Helper::isNonEmptyStr( $key ) ) {
                                continue;
                        }
                        static::$data[ $key ] = $val;
                }
//
//
//		if ( Helper::isEmptyStr( $option ) && isset( static::$data[ $option ] ) ) {
//			return false;
//		}
//
//		static::$data[ $option ] = $value;

                static::save( array_keys( $options ) );

                return true;
        }

        
        public static function setOption( $path = "", $data = "", $autoSave = true ) {

                if ( !Helper::isNonEmptyStr( $path ) ) {
                        return false;
                }

                if ( !isset( static::$data[ 'options' ] ) ) {
                        static::$data[ 'options' ] = [];
                }

                static::updateOption( $path, $data );

                if ( $autoSave ) {
                        static::save( [ 'options' ] );
                }

                return true;
        }

        
        private static function updateOption( $path = "", $value = "" ) {

                if ( !Helper::contains( $path, '/' ) ) {
                        static::$data[ 'options' ][ $path ] = $value;
                        return;
                }

                $keys = explode( '/', $path );

                $current = &static::$data[ 'options' ];

                foreach ( $keys as $count => $key ) {
                        if ( !is_array( $current ) ) {
                                $current = [];
                        }
                        if ( !isset( $current[ $key ] ) ) {
                                $current[ $key ] = []; // Create the path if it doesn't exist
                        }

                        if ( count( $keys ) <= ($count + 1) ) {
                                unset( $current[ $key ] );
                                $current[ $key ] = $value; // This is the end of the path, set the value
                        } else {
                                $current = &$current[ $key ]; // Traverse deeper into the array
                        }
                }
        }

        
        public static function setOptions( $options = [] ) {

                if ( !Helper::isNonEmptyArray( $options ) ) {
                        return false;
                }

                foreach ( $options as $option => $value ) {

                        if ( !is_numeric( $value ) && !Helper::isNonEmptyStr( $option ) ) {
                                continue;
                        }

                        static::setOption( $option, $value, false );
                }

                static::save( [ 'options' ] );

                return true;
        }

        
        public static function updateLog( $option = "" ) {

                if ( Helper::isEmptyStr( $option ) || $option === "processed" ) {
                        return false;
                }

                if ( !isset( static::$data[ 'log' ] ) ) {
                        static::$data[ 'log' ] = [];
                }
                if ( !isset( static::$data[ 'log' ][ $option ] ) ) {
                        static::$data[ 'log' ][ $option ] = 0;
                }
                if ( !isset( static::$data[ 'log' ][ 'processed' ] ) ) {
                        static::$data[ 'log' ][ 'processed' ] = 0;
                }

                static::$data[ 'log' ][ $option ]++;

                static::$data[ 'log' ][ 'processed' ]++;

                $fields = [ 'log' ];

                if ( static::$data[ 'log' ][ 'processed' ] >= static::$data[ 'total' ] ) {

                        static::$data[ 'status' ] = 'completed';

                        $fields[] = 'status';
                }

                static::save( $fields );

                return true;
        }

        
        public static function getLog( $option = "" ) {

                if ( Helper::isEmptyStr( $option ) ) {
                        return 0;
                }

                if ( isset( static::$data[ 'log' ] ) && isset( static::$data[ 'log' ][ $option ] ) ) {
                        return static::$data[ 'log' ][ $option ];
                }

                return 0;
        }

        
        public static function recordsPerIteration() {

                return RecordsPerIteration::get( static::get( 'process' ) );
        }

        
        public static function save( $fields = false ) {

                $id = parent::save( $fields );

                if ( \absint( static::get( "id" ) ) < 1 ) {
                        static::$data[ "id" ] = $id;
                }

                return $id;
        }
}
