<?php



namespace WpieApp\Modules\Export\Controller\Items\Post\Filters;

use WpieApp\Core\Utils\DB;
use WpieApp\Core\Helpers\Helper;
use WpieApp\Modules\Export\Controller\Items\Post\Filter;
use WpieApp\Modules\Export\Controller\Items\Base\Filters\Filter as BaseFilter;

defined( 'WPIE__FILE__' ) || exit;


class Taxonomy extends BaseFilter {

        
        protected static $isJoinQueryAdded = false;

        
        public static function addRule() {

                $element = Filter::getOption( "element", "field" );

                if ( !Helper::isNonEmptyStr( $element ) ) {
                        return false;
                }


                $condition      = Filter::getOption( 'condition' );
                $conditionList  = [ 'not_equals' => 'equals', 'not_contains' => 'contains', 'not_in' => 'in' ];
                $newCondition   = isset( $conditionList[ $condition ] ) ? $conditionList[ $condition ] : $condition;
                $data           = Filter::getOption( 'value' );
                $comparison     = Filter::getOption( 'comparison' );
                $queryCondition = " OR ";

                if ( !isset( $conditionList[ $condition ] ) ) {
                        //   self::addJoinQuery();
                }

                $rule = '';

                if ( "string" === $comparison ) {
                        $rule = Filter::bulidRule( self::getTableAlias( 'term' ) . '.`name`', $data, $newCondition, $comparison );
                        $rule .= $queryCondition . Filter::bulidRule( self::getTableAlias( 'term' ) . '.`slug`', $data, $newCondition, $comparison );
                }

                if ( is_numeric( $data ) ) {
                        $rule = (Helper::isNonEmptyStr( $rule ) ? $rule . $queryCondition : "") . Filter::bulidRule( self::getTableAlias( 'term' ) . '.`term_id`', $data, $newCondition, $comparison );
                }
                if ( Helper::isNonEmptyStr( $rule ) ) {

                        $condition = "IN";
                        $relation  = "OR";
                        if ( isset( $conditionList[ $condition ] ) ) {
                                $condition = "NOT IN";
                                $relation  = "AND";
                        }

                        $subQuery = self::getSubQuery( $element, $rule );

                        $rule = DB::wpdb()->posts . ".`ID` " . $condition . " (" . $subQuery . ") " . $relation . " " . DB::wpdb()->posts . ".`post_parent` " . $condition . " (" . $subQuery . ")";
                }

                Filter::addWhere( Helper::isNonEmptyStr( $rule ) ? $rule : false );
        }

        
        public static function addJoinQuery() {

                if ( self::$isJoinQueryAdded ) {
                        return;
                }

                self::$isJoinQueryAdded = true;

                $termAlias    = self::getTableAlias( 'term' );
                $termRelAlias = self::getTableAlias( 'tr' );
                $termTaxAlias = self::getTableAlias( 'tt' );

                Filter::addJoin( "LEFT JOIN " . DB::wpdb()->term_relationships . " AS " . $termRelAlias . " ON (" . DB::wpdb()->posts . ".`ID` = " . $termRelAlias . ".`object_id`)" );
                Filter::addJoin( "LEFT JOIN " . DB::wpdb()->term_taxonomy . " AS " . $termTaxAlias . " ON (" . $termTaxAlias . ".`term_taxonomy_id` = " . $termRelAlias . ".`term_taxonomy_id` )" );
                Filter::addJoin( "LEFT JOIN " . DB::wpdb()->terms . " AS " . $termAlias . " ON (" . $termAlias . ".`term_id` = " . $termTaxAlias . ".`term_id`)" );
        }

        
        private static function getSubQuery( $taxonomy = "", $rule = "" ) {

                $termAlias    = self::getTableAlias( 'term' );
                $termRelAlias = self::getTableAlias( 'tr' );
                $termTaxAlias = self::getTableAlias( 'tt' );

                return DB::wpdb()->prepare(
                                "SELECT " . DB::wpdb()->posts . ".`ID` FROM " . DB::wpdb()->posts .
                                " INNER JOIN " . DB::wpdb()->term_relationships . " AS " . $termRelAlias . " ON (" . DB::wpdb()->posts . ".`ID` = " . $termRelAlias . ".`object_id`)" .
                                " INNER JOIN " . DB::wpdb()->term_taxonomy . " AS " . $termTaxAlias . " ON (" . $termTaxAlias . ".`term_taxonomy_id` = " . $termRelAlias . ".`term_taxonomy_id`)" .
                                " INNER JOIN " . DB::wpdb()->terms . " AS " . $termAlias . " ON (" . $termAlias . ".`term_id`= " . $termTaxAlias . ".`term_id`)" .
                                " WHERE ( " . $rule . " )  AND " . $termTaxAlias . ".`taxonomy` = %s ",
                                $taxonomy
                );
        }
}
