<?php



namespace WpieApp\Modules\Import\Controller\File;

use WP_Error;
use WpieApp\Modules\Import\Helpers\Helper;
use WpieApp\Modules\Import\Controller\Settings;
use WpieApp\Core\Utils\Archive;
use WpieApp\Core\Office\Reader\Json\Reader;

defined( 'WPIE__FILE__' ) || exit;


class Bundle {

        
        public static function isBundle( $files = [] ) {

                if ( !Helper::isNonEmptyArray( $files ) || count( $files ) !== 2 || !in_array( 'config.json', $files ) ) {
                        return false;
                }

                $file = self::getFile( $files );

                if ( 'csv' !== Helper::getFileExt( $file ) ) {
                        return false;
                }

                return true;
        }

        
        public static function getFile( $files = [] ) {

                if ( !Helper::isNonEmptyArray( $files ) ) {
                        return '';
                }

                $fileList = array_diff( $files, [ 'config.json' ] );

                return array_shift( $fileList );
        }

        
        public static function setFile( $files = [] ) {

                if ( !Helper::isNonEmptyArray( $files ) ) {
                        return '';
                }

                Settings::setOption( "isBundle", "1" );

                $file = self::getFile( $files );

                $data = Setup::setFile( $file );

                if ( Helper::isNonEmptyArray( $data ) ) {
                        $data[ 'isBundle' ] = true;
                }
                return $data;
        }

        
        public static function setConfig() {

                if ( 1 !== \absint( Settings::getOption( "isBundle" ) ) ) {
                        return true;
                }

                $file = Archive::extract( Settings::getUploadFilePath(), 'config.json', [ 'outputFolder' => Settings::getCurrentDir( "upload" ) ] );

                $config = Reader::read( $file );

                if ( \is_wp_error( $config ) ) {
                        return $config;
                }
                if ( !isset( $config[ 'category' ] ) || !isset( $config[ 'content_type' ] ) ) {
                        return new WP_Error( 'wpie_import_error', __( 'Invalid config file', 'wp-import-export' ) );
                }

                Settings::set( [
                        'category'     => $config[ 'category' ],
                        'content_type' => $config[ 'content_type' ]
                ] );

                return $config[ 'category' ] . '/' . $config[ 'content_type' ];
        }

        
        public static function getFields() {

                if ( 1 !== \absint( Settings::getOption( "isBundle" ) ) ) {
                        return true;
                }

                $file = Archive::extract( Settings::getUploadFilePath(), 'config.json', [ 'outputFolder' => Settings::getCurrentDir( "upload" ) ] );

                $config = Reader::read( $file );

                if ( \is_wp_error( $config ) ) {
                        return $config;
                }

                return isset( $config[ 'fields' ] ) ? $config[ 'fields' ] : [];
        }
}
