<?php



namespace WpieApp\Modules\Import\Controller\File\Downloader\Sftp;

use WP_Error;
use WpieApp\Modules\Import\Helpers\Helper;
use WpieApp\Modules\Import\Controller\Settings;
use League\Flysystem\PhpseclibV3\SftpConnectionProvider;
use League\Flysystem\PhpseclibV3\SftpAdapter;
use League\Flysystem\UnixVisibility\PortableVisibilityConverter;
use WpieApp\Modules\Import\Controller\File\Downloader\Base\Manager as Filesystem;

defined( 'WPIE__FILE__' ) || exit;


class Manager extends Filesystem {

	
	public static function listContents() {

		$isConnect = self::connect();
		if ( is_wp_error( $isConnect ) ) {
			return $isConnect;
		}
		return parent::listContents();
	}

	
	public static function Download() {

		$isConnect = self::connect();
		if ( is_wp_error( $isConnect ) ) {
			return $isConnect;
		}
		return parent::Download();
	}

	
	private static function connect() {

		$host = Helper::removeScheme( Settings::getOption( 'uploder/options/sever' ) );
		if ( !Helper::isNonEmptyStr( $host ) ) {
			return new WP_Error( 'wpieError', __( "SFTP Server is empty", 'wp-import-export' ) );
		}

		$username = Settings::getOption( 'uploder/options/username' );
		if ( !Helper::isNonEmptyStr( $username ) ) {
			return new WP_Error( 'wpieError', __( "SFTP Server Username is empty", 'wp-import-export' ) );
		}

		$password = Settings::getOption( 'uploder/options/password' );

		$privateKey = Settings::getOption( 'uploder/options/private-key' );

		if ( !Helper::isNonEmptyStr( $password ) && !Helper::isNonEmptyStr( $privateKey ) ) {
			return new WP_Error( 'wpieError', __( "SFTP Server Password and Private Key are empty", 'wp-import-export' ) );
		}

		$path = Settings::getOption( 'uploder/options/root' );
		if ( !Helper::isNonEmptyStr( $path ) && !Helper::isNonEmptyStr( $path ) ) {
			return new WP_Error( 'wpieError', __( "SFTP Server Root Path is empty", 'wp-import-export' ) );
		}

		$privateKey	 = Helper::isNonEmptyStr( $privateKey ) ? $privateKey : null;
		$password	 = Helper::isNonEmptyStr( $password ) ? $password : null;

		$port = Helper::toInt( Settings::getOption( 'uploder/options/port' ) );

		$path = Helper::isNonEmptyStr( $path ) ? Helper::strTrim( $path, '/' ) . '/' : "";

		parent::$adapter = new SftpAdapter(
			new SftpConnectionProvider(
				$host,
				$username,
				$password,
				$privateKey,
				null,
				($port === 0 ) ? 22 : $port,
				false,
				300,
				10,
				null,
				null
			),
			$path, // root path (required)
			PortableVisibilityConverter::fromArray( [
				'file'	 => [
					'public'	 => 0640,
					'private'	 => 0604,
				],
				'dir'	 => [
					'public'	 => 0740,
					'private'	 => 7604,
				],
			] )
		);

		return true;
	}

}
