<?php



namespace WpieApp\Modules\Import\Controller\File\Downloader\Url\Downloader;

use WP_Error;
use WpieApp\Core\Admin\AutoLoader;
use WpieApp\Modules\Import\Helpers\Helper;
use WpieApp\Modules\Import\Controller\File\Downloader\Url\Downloader\Purifier\Manager as Purifier;
use WpieApp\Modules\Import\Controller\File\Downloader\Url\Downloader\FileNameFinder\Manager as FileNameFinder;
use WpieApp\Modules\Import\Controller\File\Downloader\Url\Downloader\Engine\Manager as Engine;

defined( 'WPIE__FILE__' ) || exit;


class File {

        
        Private $uri;

        
        Private $fileName;

        
        Private $extensions = [];

        
        Private $error = null;

        
        public function __construct( $url = "", $extensions = [] ) {

                $this->extensions = $extensions;

                AutoLoader::loadGeneral();
                
                $this->setUrl( $url );

                $this->setFileName();
        }

        public function download() {

                if ( \is_wp_error( $this->error ) ) {
                        return $this->error;
                }

                $file = Engine::download( $this->uri );

                if ( is_wp_error( $file ) ) {
                        return $file;
                }

//		$path = dirname( $file ) . "/" . $this->fileName;
//
//		rename( $file, $path );
                //return $path;
                return [
                        'path' => $file,
                        'name' => $this->fileName
                ];
        }

        
        public function getFilename() {

                if ( \is_wp_error( $this->error ) ) {
                        return $this->error;
                }

                return $this->fileName;
        }

        
        public function getError() {

                return $this->error;
        }

        
        private function setUrl( $url = "" ) {

                if ( !Helper::isNonEmptyStr( $url ) ) {
                        $this->error = new WP_Error( 'wpieError', __( "File Url is empty", 'wp-import-export' ) );
                        return;
                }

                $this->uri = Purifier::Purify( $url );

                if ( is_wp_error( $this->uri ) ) {
                        $this->error = $this->uri;
                }
        }

        
        private function setFileName() {

                if ( \is_wp_error( $this->error ) ) {
                        return;
                }

                $file = FileNameFinder::find( $this->uri );

                if ( \is_wp_error( $file ) ) {
                        $this->error = $file;
                        return;
                }

                $fileExt = Helper::getFileExt( $file );

                if ( !Helper::isNonEmptyArray( $this->extensions ) || !in_array( $fileExt, $this->extensions ) ) {
                        $this->error = new WP_Error( 'wpieError', __( "Invalid File Extension", 'wp-import-export' ) );
                        return;
                }

                $this->fileName = $file;
        }
}
