<?php



namespace WpieApp\Modules\Import\Controller\File\Downloader\Url\Downloader\Purifier;

use WP_Error;
use Exception;
use GuzzleHttp\Psr7\Uri;
use GuzzleHttp\Psr7\UriNormalizer;
use WpieApp\Modules\Import\Helpers\Helper;

defined( 'WPIE__FILE__' ) || exit;


class Manager {

        
        private static $uri;

        
        public static function Purify( $url = "" ) {

                if ( !Helper::isNonEmptyStr( $url ) ) {
                        return new WP_Error( 'wpieError', __( "File Url is empty", 'wp-import-export' ) );
                }

                try {
                        self::$uri = UriNormalizer::normalize( new Uri( $url ) );

                        self::fixUrl();
                } catch ( Exception $e ) {
                        return new WP_Error( 'wpieError', $e->getMessage() );
                }

                return self::$uri;
        }

        
        private static function fixUrl() {

                $host = self::$uri->getHost();

                if ( Helper::strEndsWith( $host, "dropbox.com" ) ) {

                        self::$uri = Uri::withQueryValues( self::$uri, [ 'dl' => 1 ] );
                } elseif ( Helper::strStartsWith( "drive.google.com", $host ) || Helper::strStartsWith( "docs.google.com", $host ) ) {

                        self::fixGoogleUrl();
                }
        }

        
        private static function fixGoogleUrl() {

                $path = Helper::strTrim( self::$uri->getPath(), '/' );

                $match = [];

                if ( preg_match( '/\/d\/(.+)\//', $path, $match ) !== 1 ) {
                        return;
                }

                $fileId = (is_array( $match ) && isset( $match[ 1 ] ) ) ? $match[ 1 ] : "";

                if ( !Helper::isNonEmptyStr( $fileId ) ) {
                        return;
                }

                $url = "";

                if ( Helper::strStartsWith( 'spreadsheets', $path ) ) {
                        $url = 'https://docs.google.com/spreadsheets/d/' . $fileId . '/export?format=xlsx';
                } elseif ( Helper::strStartsWith( 'file', $path ) ) {
                        $url = 'https://drive.google.com/uc?export=download&id=' . $fileId;
                }

                if ( !Helper::isNonEmptyStr( $url ) ) {
                        return;
                }

                self::$uri = UriNormalizer::normalize( new Uri( $url ) );
        }
}
