<?php



namespace WpieApp\Modules\Import\Controller\File\Parser;

use WP_Error;
use WpieApp\Core\Office\Converter;
use WpieApp\Core\Utils\Archive;
use WpieApp\Core\Resource\Resource;
use WpieApp\Modules\Import\Helpers\Helper;
use WpieApp\Modules\Import\Controller\Settings;
use WpieApp\Core\Office\Converter\Excel\Excel;
use WpieApp\Core\Office\Converter\Json2Xml;

defined( 'WPIE__FILE__' ) || exit;


class Manager {

        
        private static $file = '';

        
        private static $retry = '';

        
        public static function init( $retry = 0 ) {

                self::$file = Settings::getOption( 'file/name' );

                if ( !Helper::isNonEmptyStr( self::$file ) ) {
                        self::$file = Settings::get( "file" );
                }

                Resource::increase();

                $isCompleted = self::start();

                if ( $isCompleted !== false ) {
                        return $isCompleted;
                }

                self::$retry = $retry;

                return self::convert();
        }

        
        private static function start() {

                $status = Settings::getOption( 'file/parser/status' );

                if ( Helper::isNonEmptyStr( $status ) ) {

                        if ( "completed" === $status ) {
                                return [ 'status' => "completed" ];
                        }
                        return false;
                }

                Settings::createImportDir( 'file' );

                Settings::setOption( 'file/parser/status', 'start' );

                if ( !self::tryEasyParse() ) {
                        return false;
                }

                return [ 'status' => "completed" ];
        }

        
        private static function tryEasyParse() {

                $ext = Helper::getFileExt( self::$file );

                if ( !in_array( $ext, [ 'xml', 'csv' ] ) ) {
                        return false;
                }

                Settings::setOption( "file/format", $ext );

                Settings::setOption( 'file/parser/status', 'completed' );

                return Helper::duplicate( Settings::getCurrentDir( "upload" ) . DIRECTORY_SEPARATOR . self::$file, Settings::getImportFilePath() );
        }

        
        private static function convert() {

                if ( Helper::supportMultipleSheets( self::$file ) ) {
                        return self::toExcel();
                } else {
                        return self::toXml();
                }
        }

        
        private static function toExcel() {

                if ( "csv" !== Settings::getOption( "file/format" ) ) {
                        Settings::setOption( "file/format", 'csv' );
                }

                $file = Settings::getCurrentDir( "upload" ) . DIRECTORY_SEPARATOR . self::$file;

                $dest = Settings::getImportFilePath();

                $options = [
                        'sheet' => Settings::getOption( "file/sheet/name" ),
                        'start' => Settings::getOption( "file/sheet/start" ),
                        'retry' => self::$retry
                ];

                if ( absint( $options[ 'start' ] ) < 1 ) {
                        Helper::deleteFile( $dest );
                }

                $process = Excel::convert( $file, $dest, $options );

                if ( is_array( $process ) && isset( $process[ 'start' ] ) && Helper::toInt( $process[ 'start' ] ) > 0 ) {
                        Settings::setOption( "file/sheet/start", Helper::toInt( $process[ 'start' ] ) );
                }

                return $process;
        }

        
        private static function toXml() {

                if ( "xml" !== Settings::getOption( "file/format" ) ) {
                        Settings::setOption( "file/format", 'xml' );
                }

                $file = Settings::getCurrentDir( "upload" ) . DIRECTORY_SEPARATOR . self::$file;

                $ext = Helper::getFileExt( self::$file );

                if ( "json" === $ext ) {

                        $isSuccess = Json2Xml::convert( $file, Settings::getImportFilePath() );

                        Settings::setOption( 'file/parser/status', 'completed' );

                        if ( \is_wp_error( $isSuccess ) ) {
                                return $isSuccess;
                        }

                        return [ "status" => "completed" ];
                }
        }
}
