<?php



namespace WpieApp\Modules\Import\Controller\Items\Base;

use WpieApp\Modules\Import\Helpers\Helper;
use WpieApp\Modules\Import\Controller\Items\Base\AutoDetect\Record;
use WpieApp\Modules\Import\Controller\Items\Base\AutoDetect\Export;

defined( 'WPIE__FILE__' ) || exit;


class AutoDetect {

        
        protected static $fields = [];

        
        protected static $siteFields = [];

        
        protected static $meta = [];

        
        protected static $canUpdate = [];

        
        protected static $labels = [];

        
        public static function get() {

                static::init();

                return [ 'fields' => static::$fields, "can-update" => static::$canUpdate ];
        }

        
        protected static function init() {

                static::reset();

                if ( !Helper::isNonEmptyArray( static::$labels ) ) {
                        return;
                }

                static::setDefaults();

                static::processFields();

                static::processMetaFields();

                static::processExtra();

                static::DiscoverAlternative();

                \do_action( 'Wpie/Import/Base/AutoDetect/End' );
        }

        
        public static function getLabels() {
                return static::$labels;
        }

        
        protected static function processExtra() {
                
        }

        
        protected static function DiscoverAlternative() {
                
        }

        
        protected static function setDefaults() {
                
        }

        
        protected static function processFields() {

                foreach ( static::$labels as $field ) {

                        \do_action( 'Wpie/Import/Base/AutoDetect', $field );

                        static::processField( $field );
                }
        }

        
        protected static function processField( $field = '' ) {
                
        }

        
        protected static function processMetaFields() {

                static::processMeta();

                if ( Helper::isNonEmptyArray( static::$meta ) ) {
                        static::updateList( 'meta' );
                }

                static::$fields[ 'meta' ] = [ 'data' => static::$meta ];
        }

        
        protected static function processMeta() {

                $metas = static::getSiteFieldData( 'meta' );

                if ( !Helper::isNonEmptyArray( $metas ) ) {
                        return;
                }

                foreach ( $metas as $meta ) {

                        $key = isset( $meta[ 'element' ] ) ? $meta[ 'element' ] : '';

                        $label = isset( $meta[ 'label' ] ) ? Helper::sanitizeKey( $meta[ 'label' ] ) : '';

                        $val = ( Helper::isNonEmptyStr( $label ) && in_array( $label, static::$labels ) ) ? $label : '';

                        static::updateMeta( $key, $val );
                }
        }

        
        private static function reset() {
                static::$fields     = [];
                static::$meta       = [];
                static::$canUpdate  = [];
                static::$labels     = Record::getLabels();
                static::$siteFields = Export::getFields();
        }

        
        public static function hasField( $path = '' ) {

                return '1' === Helper::subArray( static::$canUpdate, $path );
        }
        
        
        public static function getField( $path = '' ) {

              return  Helper::subArray( static::$fields, $path);
        }

        
        public static function update( $path = '', $value = '' ) {

                static::updateList( $path );

                static::updateField( $path . '/data', $value );
        }

        
        public static function updateList( $path = '' ) {

                Helper::updateNestedArray( static::$canUpdate, $path, '1' );
        }

        
        public static function updateField( $path = '', $value = '', $format = true ) {

                Helper::updateNestedArray( static::$fields, $path, ($format ? static::formatField( $value ) : $value ) );
        }

        
        public static function updateMeta( $key = '', $value = '' ) {

                static::$meta[] = [ "key" => $key, "val" => static::formatField( $value ) ];
        }

        
        public static function formatField( $field = '' ) {

                if ( is_array( $field ) ) {
                        return array_map( [ __CLASS__, "formatField" ], $field );
                }

                return Helper::isNonEmptyStr( $field ) ? '{' . $field . '}' : '';
        }

        
        public static function getSiteFieldData( $key = '' ) {

                if ( !Helper::isNonEmptyArray( static::$siteFields ) || !isset( static::$siteFields[ $key ] ) || !isset( static::$siteFields[ $key ][ 'data' ] ) || !Helper::isNonEmptyArray( static::$siteFields[ $key ][ 'data' ] ) ) {
                        return [];
                }

                return static::$siteFields[ $key ][ 'data' ];
        }

        
        public static function getSiteFields() {

                return static::$siteFields;
        }
}
