<?php


namespace WpieApp\Modules\Import\Controller\Items\Base;

use WpieApp\Modules\Import\Controller\Settings;
use WpieApp\Modules\Import\Helpers\Helper;
use WpieApp\Core\Page\Blocks\Fields\Checkbox;
use WpieApp\Core\Page\Blocks\Fields\Alert;
use WpieApp\Core\Page\Blocks\Blocks;
use WpieApp\Core\Page\Blocks\Templates\Standard\Manager as StandardManager;

defined( 'WPIE__FILE__' ) || exit;


class Fields {

        
        protected static $data = [];

        
        public static function get() {

                $type = Settings::getContentType();

                
                \do_action( 'Wpie/Import/Base/Fields/Init', $type );

                
                return \apply_filters( 'Wpie/Import/Base/Fields', static::getFields(), $type );
        }

        
        public static function getFields() {

                return [];
        }

        
        protected static function getHtml() {

                if ( !Helper::isNonEmptyArray( static::$data ) ) {
                        return;
                }

                static::$data = Helper::sortBy( static::$data, "order" );

                $html = "";

                foreach ( static::$data as $section ) {
                        $html .= static::getSection( $section );
                }

                return $html;
        }

        
        protected static function getSection( $section = [] ) {

                if ( !Helper::isNonEmptyArray( $section ) ) {
                        return;
                }
                if ( !isset( $section[ 'blocks' ] ) || !Helper::isNonEmptyArray( $section[ 'blocks' ] ) ) {
                        return;
                }

                $section[ 'blocks' ] = Helper::sortBy( $section[ 'blocks' ] );

                $hideBulkCheck = (isset( $section[ 'hide-bulk-check' ] ) && $section[ 'hide-bulk-check' ] === true) ? true : false;

                $section[ 'group-name' ] = isset( $section[ 'group-name' ] ) ? Helper::toString( $section[ 'group-name' ] ) : "";

                $proBackdrop = isset( $section[ "pro-backdrop" ] ) && $section[ "pro-backdrop" ] === true ? true : false;

                $uid = Helper::randStr( "wpie-block-" );

                \ob_start();
                ?>
                <div class="col-lg-4 mt-5">
                        <div class="list-group shadow-sm mb-4 small wpie-field-group position-relative" field="<?php echo \esc_html( $uid ); ?>">
                                <?php
                                if ( $proBackdrop ) {
                                        StandardManager::addProBackdrop();
                                }
                                ?>
                                <div class="list-group-item p-3 bg-primary bg-opacity-10 text-center">
                                        <div class="my-1 p-0 bse-fs-18 bse-fw-500"><?php echo isset( $section[ 'label' ] ) ? esc_html( $section[ 'label' ] ) : ""; ?></div>
                                </div>
                                <?php
                                $isAdded = false;
                                foreach ( $section[ 'blocks' ] as $key => $block ) {

                                        if ( !Helper::isNonEmptyArray( $block ) ) {
                                                continue;
                                        }
                                        $menuClass                                  = Helper::randStr( "wpie-menu-" );
                                        $section[ 'blocks' ][ $key ][ "uid" ]       = $menuClass;
                                        $section[ 'blocks' ][ $key ][ "menuClass" ] = $menuClass;

                                        if ( $isAdded === false && isset( $section[ 'blocks' ][ $key ][ "order" ] ) && $section[ 'blocks' ][ $key ][ "order" ] > 0 && !$hideBulkCheck ) {
                                                $isAdded = true;
                                                static::getBlock( [ "title" => __( 'All Fields', 'wp-import-export' ), "field-class" => "bse-fw-600 wpie-check-all", "is-field" => false ] );
                                        }
                                        static::getBlock( $section[ 'blocks' ][ $key ], $key );
                                }
                                if ( \count( $section[ 'blocks' ] ) > 3 ) {
                                        ?>
                                        <div class="list-group-item wpie-field-selection d-flex align-items-center justify-content-between bg-primary bg-opacity-10">
                                                <button type="button" class="btn btn-primary m-auto wpie-btn-show-hide-fields btn-show-all"><i class="fa-regular fa-eye me-1"></i><?php esc_html_e( 'Show All', 'wp-import-export' ); ?></button>
                                        </div>
                                        <?php
                                }
                                ?>
                        </div>
                        <div class="modal fade <?php echo esc_html( $uid ); ?> wpie-edit-field-container">
                                <div class="modal-dialog modal-fullscreen">
                                        <div class="modal-content">
                                                <div class="modal-header">
                                                        <h5 class="modal-title" ><?php echo isset( $section[ 'label' ] ) ? esc_html( $section[ 'label' ] . " " . __( 'Fields', 'wp-import-export' ) ) : ""; ?></h5>
                                                        <!--							<button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>-->
                                                        <div class="align-right ms-auto">
                                                                <button type="button" class="btn btn-secondary wpie-btn-cancel me-2" data-bs-dismiss="modal" aria-label="Close"><i class="bse-fs-14 me-1 fa-solid fa-close"></i><?php esc_html_e( 'Cancel', 'wp-import-export' ); ?></button>
                                                                <button type="button" class="btn btn-primary wpie-save-field-btn" ><i class="bse-fs-14 me-1 fa-solid fa-check"></i><?php esc_html_e( 'Save', 'wp-import-export' ); ?></button>
                                                        </div>
                                                </div>
                                                <div class="modal-body bg-light pt-0">

                                                        <div class="row">
                                                                <div class="col-sm-6 col-xl-8 pe-0">
                                                                        <?php
                                                                        Alert::addNotes( [
                                                                                [
                                                                                        "type"       => "success",
                                                                                        "icon-class" => "fa-solid fa-circle-info ",
                                                                                        "class"      => "mb-0 wpie-drag-and-drop-mapping-alert mt-3 me-3",
                                                                                        "text"       => __( 'Drag and drop any field from the table header or XML tag.', 'wp-import-export' )
                                                                                ],
                                                                                [
                                                                                        "type"       => "info",
                                                                                        "icon-class" => "fa-solid fa-circle-info ",
                                                                                        "class"      => "mb-0 wpie-drag-and-drop-mapping-alert mt-3 me-3",
                                                                                        "text"       => sprintf(
                                                                                                /* translators: Link to the field mapping documentation. */
                                                                                                __(
                                                                                                        '<a href="%s" target="_blank" class="wpie-info-alert-link">Click here</a> to learn the step-by-step guide on mapping fields.',
                                                                                                        'wp-import-export'
                                                                                                ),
                                                                                                \esc_url( WPIE_DOC_URL . 'field-mapping' )
                                                                                        )
                                                                                ]
                                                                        ] );
                                                                        Blocks::render( [ $section ] );
                                                                        ?>
                                                                </div>
                                                                <div class="col-sm-6 col-xl-4 ps-0 position-ralative">
                                                                        <div class="wpie-mapping-fields mt-3"></div>
                                                                </div>
                                                        </div>
                                                </div>
                                        </div>
                                </div>
                        </div>
                </div>
                <?php
                return \ob_get_clean();
        }

        
        protected static function getBlock( $block = [], $key = "" ) {

                if ( !Helper::isNonEmptyArray( $block ) ) {
                        return;
                }

                $title         = isset( $block[ 'title' ] ) ? $block[ 'title' ] : "";
                $subTitle      = isset( $block[ 'sub-title' ] ) ? $block[ 'sub-title' ] : "";
                $fieldClass    = isset( $block[ "field-class" ] ) ? $block[ "field-class" ] : "";
                $uid           = isset( $block[ "uid" ] ) && Helper::isNonEmptyStr( $block[ "uid" ] ) ? $block[ "uid" ] : "";
                $isField       = isset( $block[ "is-field" ] ) ? $block[ "is-field" ] : true;
                $isRecommended = isset( $block[ "isRecommended" ] ) && $block[ "isRecommended" ] === true ? true : false;
                $itemClass     = $isField ? "wpie-field-menu-item" : "";
                $key           = Helper::isNonEmptyStr( $key ) ? $key : Helper::sanitizeKey( $title );

                $name = $isField ? "wpie-settings[can-update][" . Helper::arrTostr( Helper::strToArr( $key, '/' ), "][" ) . "]" : "";

                $blockType = isset( $block[ 'block-type' ] ) ? $block[ 'block-type' ] : "";

                $colorClass = "text-primary bg-primary";
                if ( $blockType === "options" ) {
                        $colorClass = "text-success bg-success";
                }

                //$fieldClass .= " bse-form-check-danger ";
                ?>
                <div class="list-group-item wpie-field-selection d-flex align-items-center justify-content-between p-3 <?php echo esc_attr( $itemClass ); ?>" block="<?php echo esc_attr( $uid ); ?>">
                        <div class="container m-0 p-0">
                                <div class="row align-items-center m-0 p-0 justify-content-end">
                                        <div class="col-auto m-auto ms-0 p-0 align-static-start"><?php $blockType === "options" ? static::getSettings( $title ) : Checkbox::render( [ "choices" => [ 1 => $title ], "hints" => [ 1 => $subTitle ], "field-class" => $fieldClass . " form-switch ", "name" => $name, "class" => "wpie-can-update-checkbox" ] ); ?></div>
                                        <?php if ( $isRecommended ) { ?><div class="col-auto p-0 align-static-end"><div class="py-2 px-3 bg-opacity-10 rounded-3 me-3 text-warning bg-warning " data-bs-toggle="tooltip" data-bs-title="<?php esc_attr_e( 'Important fields for new items', 'wp-import-export' ); ?>"><i class="fa-solid fa-star fa-xs text-gray-400"></i></div></div><?php } ?>
                                        <div class="col-auto m-0 p-0 align-static-end my-auto"><div class="py-2 px-3 bg-opacity-10 rounded-3  bse-cursor-pointer wpie-field-edit <?php echo esc_attr( $colorClass ); ?>"><i class="fa-solid fa-pen fa-xs text-gray-400 bse-cursor-pointer"></i></div></div>
                                </div>
                        </div>
                </div>
                <?php
        }

        
        private static function getSettings( $title ) {
                ?>

                <div class="text-success"><i class="fa-solid fa-gear me-2 fa-lg "></i><?php echo esc_html( $title ); ?></div>

                <?php
        }
}
