<?php



namespace WpieApp\Modules\Import\Controller\Items\Post\Engines;

use WpieApp\Core\Utils\DB;
use WpieApp\Modules\Import\Helpers\Helper;
use WpieApp\Modules\Import\Controller\Settings;
use WpieApp\Modules\Import\Controller\Items\Base\Process;
use WpieApp\Modules\Import\Controller\Items\Base\Logger;
use WpieApp\Modules\Import\Controller\Items\Post\DataCenter;
use WpieApp\Modules\Import\Controller\Items\Post\Engines\Images\Source;
use WpieApp\Modules\Import\Controller\Items\Post\Engines\Images\Existing;
use WpieApp\Modules\Import\Controller\Items\Post\Engines\Images\Attachment;
use WpieApp\Modules\Import\Controller\Items\Base\Engines\Image as BaseImage;

defined( 'WPIE__FILE__' ) || exit;


class Image extends BaseImage {

        
        public static function import() {

                $sourceAdded = Source::import();

                if ( Process::isPending() ) {
                        return;
                }

                if ( $sourceAdded ) {
                        self::removeImages();
                }

                $detailsAdded = Attachment::import();

                if ( $sourceAdded || $detailsAdded ) {
                        /* translators: %s: content type */
                        Logger::log( sprintf( __( "%s Images Imported", 'wp-import-export' ), Settings::getContentLabel() ) );
                }
        }

        
        protected static function getExistingImage() {

                if ( DataCenter::isNewItem() || !DataCenter::canUpdate( "images/source" ) || DataCenter::get( "images/options/manage-existing" ) !== "remove" ) {
                        return;
                }

                $existingAttachments = Existing::getAttachments();

                if ( empty( $existingAttachments ) ) {
                        return false;
                }

                $newAttachments = Source::getAttachments();

                return array_diff( $existingAttachments, $newAttachments );
        }

        
        protected static function unlinkImage( $attachments = [] ) {

                if ( !Helper::isNonEmptyArray( $attachments ) ) {
                        return false;
                }

                $attachmentList = implode( ',', array_map( "absint", $attachments ) );

                DB::wpdb()->query( "UPDATE " . DB::wpdb()->posts . " SET post_parent = 0 WHERE post_type = 'attachment' AND ID IN ( $attachmentList )" );

                foreach ( $attachments as $id ) {
                        \clean_attachment_cache( $id );
                }
        }

        
        protected static function removeSource( $attachments = [] ) {

                if ( !Helper::isNonEmptyArray( $attachments ) ) {
                        return false;
                }

                foreach ( $attachments as $id ) {
                        \wp_delete_attachment( $id, true );
                }
        }
}
