<?php



namespace WpieApp\Modules\Import\Controller\Items\Post\Engines;

use WpieApp\Core\Utils\DB;
use WpieApp\Core\Helpers\Helper;
use WpieApp\Modules\Import\Controller\Settings;
use WpieApp\Modules\Import\Controller\Items\Post\Search;
use WpieApp\Modules\Import\Controller\Items\Base\Logger;
use WpieApp\Modules\Import\Controller\Items\Post\DataCenter;

defined( 'WPIE__FILE__' ) || exit;


class Other {

        
        public static function get() {

                $data = [];

                if ( DataCenter::canUpdate( "standard/post_status" ) ) {

                        $status = DataCenter::get( "standard/post_status/data" );

                        $status = Helper::isNonEmptyStr( $status ) ? Helper::autoFixStr( $status, \get_post_stati() ) : "";

                        if ( Helper::isNonEmptyStr( $status ) ) {

                                $data[ "post_status" ] = $status;
                        }
                }

                if ( DataCenter::isNewItem() && !isset( $data[ "post_status" ] ) ) {
                        $data[ "post_status" ] = "publish";
                }

                if ( DataCenter::canUpdate( "standard/comment_status" ) ) {

                        $data[ "comment_status" ] = (false === Helper::detectBoolVal( DataCenter::get( "standard/comment_status/data" ) )) ? 'closed' : 'open';
                }

                if ( DataCenter::canUpdate( "standard/ping_status" ) ) {

                        $data[ "ping_status" ] = (false === Helper::detectBoolVal( DataCenter::get( "standard/ping_status/data" ) )) ? 'closed' : 'open';
                }

                if ( DataCenter::canUpdate( "standard/post_password" ) ) {

                        $postPassword = DataCenter::get( "standard/post_password/data" );

                        if ( Helper::isNonEmptyStr( $postPassword ) ) {

                                $data[ "post_password" ] = $postPassword;
                        }
                }
                if ( DataCenter::canUpdate( "standard/post_parent" ) ) {

                        $data[ "post_parent" ] = self::getParent();
                }

                if ( DataCenter::canUpdate( "standard/menu_order" ) ) {

                        $menuOrder = DataCenter::get( "standard/menu_order/data" );

                        if ( Helper::isNonEmptyStr( $menuOrder ) ) {

                                $data[ "menu_order" ] = $menuOrder;
                        }
                }
                if ( DataCenter::canUpdate( "standard/page_template" ) ) {

                        $pageTemplate = DataCenter::get( "standard/page_template/data" );

                        if ( Helper::isNonEmptyStr( $pageTemplate ) ) {

                                $data[ "page_template" ] = $pageTemplate;
                        }
                }

                return $data;
        }

        
        private static function getParent() {

                $postParent = DataCenter::get( "standard/post_parent/data" );

                if ( !Helper::isNonEmptyStr( $postParent ) || (is_numeric( $postParent ) && 1 > absint( $postParent ) ) ) {
                        return 0;
                }

                $options = [
                        [
                                "args" => [
                                        [ "key" => 'title', "value" => $postParent ],
                                        [ "key" => 'content', "value" => $postParent, "relation" => "or" ],
                                        [ "key" => 'slug', "value" => $postParent, "relation" => "or" ],
                                        [ "key" => 'id', "value" => $postParent, "relation" => "or", 'is_int' => true, 'conditions' => [ 'positive_number_only' ] ],
                                ]
                        ],
                        [
                                "relation" => "and",
                                "args"     => [
                                        [ "key" => "type", "value" => Settings::get( 'content_type' ) ]
                                ]
                        ]
                ];

                return Search::getId( $options );
        }

        
        public static function setProp() {
                self::setPostFormat();
                self::setStickyPost();
        }

        
        private static function setPostFormat() {

                if ( !DataCenter::canUpdate( "standard/post_format" ) ) {
                        return;
                }

                $postFormat = Helper::autoFixStr( DataCenter::get( "standard/post_format/data" ), array_keys( get_post_format_strings() ), 5 );

                if ( !Helper::isNonEmptyStr( $postFormat ) ) {
                        return;
                }

                if ( DataCenter::isNewItem() && $postFormat === "standard" ) {
                        return;
                }

                $setFormat = \set_post_format( DataCenter::getItem(), $postFormat );

                if ( is_wp_error( $setFormat ) ) {
                        Logger::log( "<strong>" . __( 'ERROR', 'wp-import-export' ) . '</strong> : ' . $setFormat->get_error_message() );
                }
        }

        
        private static function setStickyPost() {

                if ( !DataCenter::canUpdate( "standard/stick_post" ) ) {
                        return;
                }

                $isStickyPost = Helper::autoFixStr( DataCenter::get( "standard/stick_post/data" ), [ "yes", "no" ] );

                if ( !Helper::isNonEmptyStr( $isStickyPost ) ) {
                        return;
                }

                if ( $isStickyPost === "yes" ) {
                        \stick_post( DataCenter::getId() );
                } elseif ( $isStickyPost === "no" ) {
                        \unstick_post( DataCenter::getId() );
                }
        }
}
