<?php



namespace WpieApp\Modules\Import\Controller\Items\Term;

use WpieApp\Modules\Import\Helpers\Helper;
use WpieApp\Modules\Import\Controller\Items\Term\Search\Meta;

defined( 'WPIE__FILE__' ) || exit;


class Search {

        
        public static function getTermIdByMeta( $key = '', $val = '' ) {
                return Meta::Search( $key, $val );
        }

        
        public static function getTermIdBy( $field = '', $value = '', $taxonomy = '' ) {

                $term = self::getTerm( $field, $value, $taxonomy );

                return ($term !== false && isset( $term->term_id ) ? $term->term_id : 0);
        }

        
        public static function findTerm( $field = 'all', $value = '', $taxonomy = '', $arg = [] ) {

                if ( !Helper::isNonEmptyStr( $value ) && !is_numeric( $value ) ) {
                        return 0;
                }

                $baseFields = [ 'name', 'term_id', 'slug' ];

                $fields = Helper::isNonEmptyStr( $field ) && in_array( $field, $baseFields ) ? [ $field ] : [ 'slug', 'name', 'term_id' ];

                $id = 0;

                $arg = Helper::isNonEmptyArray( $arg ) ? $arg : [];

                $arg[ 'taxonomy' ] = $taxonomy;

                foreach ( $fields as $searchField ) {

                        if ( 'term_id' === $searchField && !is_numeric( $value ) ) {
                                continue;
                        }

                        $tempArg = $arg;

                        $tempArg[ $searchField ] = $value;

                        $terms = self::getTerms( $tempArg );

                        if ( false === $terms || \is_wp_error( $terms ) || 1 > count( $terms ) ) {
                                continue;
                        }

                        $id = array_shift( $terms );

                        break;
                }

                return is_numeric( $id ) ? \absint( $id ) : $id;
        }

        
        public static function getTerm( $field = '', $value = '', $taxonomy = '' ) {

                if ( !Helper::isNonEmptyStr( $field ) || (!Helper::isNonEmptyStr( $value ) && !is_numeric( $value )) || !Helper::isNonEmptyStr( $taxonomy ) ) {
                        return false;
                }

                return \get_term_by( $field, $value, $taxonomy );
        }

        
        public static function getTerms( $args = [] ) {

                if ( !Helper::isNonEmptyArray( $args ) ) {
                        return false;
                }

                $taxonomy = isset( $args[ 'taxonomy' ] ) ? $args[ 'taxonomy' ] : '';

                if ( !Helper::isNonEmptyStr( $taxonomy ) ) {
                        return false;
                }

                $defaults = [
                        'cache_results'          => false,
                        'get'                    => 'all',
                        'update_term_meta_cache' => false,
                        'suppress_filter'        => true,
                        'fields'                 => 'ids',
                ];

                $args = array_replace( $defaults, $args );

                global $wp_version;
                // Ignoring deprecated parameter warning for get_terms() 
                // since this code is only executed for WordPress versions lower than 4.5.0
                // phpcs:ignore WordPress.WP.DeprecatedParameters.Get_termsParam2Found
                return version_compare( $wp_version, '4.5.0', '<' ) ? \get_terms( $taxonomy, $args ) : \get_terms( $args );
        }
}
