<?php



namespace WpieApp\Modules\Logs\Controller;

use WpieApp\Core\Utils\DB;
use WpieApp\Core\Utils\Date;
use WpieApp\Core\Helpers\Helper;

defined( 'WPIE__FILE__' ) || exit;


class ManageLog {

        
        private static $timeLimit = null;

        
        public static function cleanUp() {

                self::setTimeLimit();

                self::pauseProcess();

                self::LimitLogs();

                self::removeDrafts();
        }

        
        public static function pauseProcess() {

                return DB::wpdb()->query( DB::wpdb()->prepare( "UPDATE " . DB::getPluginTable() . " SET `status` = 'paused' WHERE `status` IN ('processing','waiting') AND `process_type` = 'regular' AND `updated_date` < %s ", self::$timeLimit ) );
        }

        
        public static function LimitLogs() {

                $settingData = Helper::getOption( 'settings', "" );

                $settings = Helper::isNonEmptyStr( $settingData ) ? maybe_unserialize( $settingData ) : [];

                $limit = !isset( $settings[ "log-limit" ] ) || $settings[ "log-limit" ] < 10 || $settings[ "log-limit" ] > 50 ? 25 : $settings[ "log-limit" ];

                self::removeErrorLogs( $limit );

                $dirs = DB::wpdb()->get_col( DB::wpdb()->prepare( "SELECT `filedir` FROM " . DB::getPluginTable() . " WHERE `status` != 'draft' AND `process_type` = 'regular' AND `id` NOT IN ( SELECT `id` FROM ( SELECT `id` FROM " . DB::getPluginTable() . " WHERE `status` != 'draft' AND `process` = 'export' AND `process_type` = 'regular' ORDER BY `id` DESC LIMIT 0,%d) temp_a ) AND `id` NOT IN ( SELECT `id` FROM (SELECT `id` FROM " . DB::getPluginTable() . " WHERE `status` != 'draft' AND `process` = 'import' AND `process_type` = 'regular' ORDER BY `id` DESC LIMIT 0,%d ) temp_b )", $limit, $limit ) );

                if ( !Helper::isNonEmptyArray( $dirs ) ) {
                        return true;
                }

                Helper::removeDir( $dirs );

                return DB::wpdb()->query( DB::wpdb()->prepare( "DELETE FROM " . DB::getPluginTable() . " WHERE `status` != 'draft' AND `process_type` = 'regular' AND `id` NOT IN ( SELECT `id` FROM ( SELECT `id` FROM " . DB::getPluginTable() . " WHERE `status` != 'draft' AND `process` = 'export' AND `process_type` = 'regular' ORDER BY `id` DESC LIMIT 0,%d) temp_a ) AND `id` NOT IN ( SELECT `id` FROM (SELECT `id` FROM " . DB::getPluginTable() . " WHERE `status` != 'draft' AND `process` = 'import' AND `process_type` = 'regular' ORDER BY `id` DESC LIMIT 0,%d ) temp_b )", $limit, $limit ) );
        }

        
        public static function removeDrafts() {

                $dirs = DB::wpdb()->get_col( DB::wpdb()->prepare( "SELECT `filedir` FROM " . DB::getPluginTable() . " WHERE `status` = 'draft' AND `process_type` = 'regular' AND `updated_date` < %s ", self::$timeLimit ) );

                if ( !Helper::isNonEmptyArray( $dirs ) ) {
                        return true;
                }

                Helper::removeDir( $dirs );

                return DB::wpdb()->query( DB::wpdb()->prepare( "DELETE FROM " . DB::getPluginTable() . " WHERE `status` = 'draft' AND `process_type` = 'regular' AND `updated_date` < %s ", self::$timeLimit ) );
        }

        
        private static function removeErrorLogs( $limit = 25 ) {

                if ( !Helper::getFilesystem()->is_dir( WPIE_LOG_DIR ) ) {
                        return;
                }
                $files = scandir( WPIE_LOG_DIR );

                $debugFiles = Helper::isNonEmptyArray( $files ) ? array_diff( $files, [ '.', '..', '.htaccess', 'index.html' ] ) : [];

                if ( !Helper::isNonEmptyArray( $debugFiles ) ) {
                        return true;
                }

                arsort( $debugFiles );

                $debugFiles = array_slice( $debugFiles, $limit );

                foreach ( $debugFiles as $file ) {

                        Helper::deleteFile( Helper::pathJoin( WPIE_LOG_DIR, $file ) );
                }
        }

        
        public static function removeLogs( $ids = [] ) {

                if ( !Helper::isNonEmptyArray( $ids ) ) {
                        return false;
                }

                $placeholders = implode( ', ', array_fill( 0, count( $ids ), '%d' ) );

                $dirs = DB::wpdb()->get_col( DB::wpdb()->prepare( "SELECT `filedir` FROM " . DB::getPluginTable() . " WHERE `id` IN ($placeholders)", $ids ) );

                if ( !Helper::isNonEmptyArray( $dirs ) ) {
                        return true;
                }

                Helper::removeDir( $dirs );

                return DB::wpdb()->query( DB::wpdb()->prepare( "DELETE FROM " . DB::getPluginTable() . " WHERE `id` IN ($placeholders)", $ids ) );
        }

        
        private static function setTimeLimit() {

                $currentTime = Date::now();

                self::$timeLimit = Date::getCoreDate( Date::FORMAT, strtotime( '-1 hours', strtotime( $currentTime ) ) );
        }
}
