<?php



namespace WpieApp\Modules\Schedules\Controller;

use WP_Error;
use WpieApp\Core\Utils\Date;
use WpieApp\Core\Helpers\Helper;
use WpieApp\Core\Logger\Logger;

defined( 'WPIE__FILE__' ) || exit;


class Event {

        
        const EVENT_HOOK = 'WpieApp/Schedule/Start';

        
        public static function add( $id = 0, $interval = "", $startTime = "" ) {

                $schedules = \wp_get_schedules();

                if ( !Helper::isNonEmptyStr( $interval ) || !isset( $schedules[ $interval ] ) ) {

                        return new WP_Error( 'wpieError', __( 'Schedules interval is invalid', 'wp-import-export' ) );
                }

                $startTime = (Helper::isNonEmptyStr( $startTime ) ? self::getTime( $startTime ) : self::getTime( "now" ));

                $event = \wp_schedule_event( $startTime, $interval, self::EVENT_HOOK, [ $id ], true );

                if ( \is_wp_error( $event ) ) {
                        return $event;
                }

                return true;
        }

        
        public static function remove( $ids = [] ) {

                if ( is_numeric( $ids ) ) {
                        $ids = [ $ids ];
                }

                if ( !Helper::isNonEmptyArray( $ids ) ) {
                        return;
                }

                foreach ( $ids as $id ) {

                        if ( absint( $id ) < 1 ) {
                                continue;
                        }
                        $result = \wp_clear_scheduled_hook( self::EVENT_HOOK, [ absint( $id ) ], true );

                        if ( \is_wp_error( $result ) ) {
                                Logger::log( $result->get_error_message() );
                        }
                }
        }

        
        private static function getTime( $time = "" ) {
                // Create a DateTime object with the provided time in the local timezone
                $LocalTime = new \DateTime( $time, Date::getTimeZone() );

                // Convert the time to UTC
                $LocalTime->setTimezone( new \DateTimeZone( 'UTC' ) );

                if ( 'now' !== $time ) {
                        // Current time in UTC
                        $currentTime = new \DateTime( 'now', Date::getTimeZone() );

                        if ( $LocalTime <= $currentTime ) {
                                // Move to the next day if the time has already passed
                                $LocalTime->modify( '+1 day' );
                        }
                }

                // Return the Unix timestamp
                return $LocalTime->getTimestamp();
        }

        
        public static function deactivate() {

                \wp_clear_scheduled_hook( self::EVENT_HOOK );
        }
}
