<?php



namespace WpieApp\Modules\Schedules\Controller;

use WpieApp\Core\Utils\DB;
use WpieApp\Core\Utils\Cron;
use WpieApp\Core\Helpers\Helper;
use WpieApp\Modules\Export\Controller\Schedule as ExportSchedule;
use WpieApp\Modules\Import\Controller\Schedule as ImportSchedule;
use WpieApp\Modules\Import\Cron as ImportCron;
use WpieApp\Extensions\Manager as Extensions;

defined( 'WPIE__FILE__' ) || exit;


class Schedule {

        
        public static function init() {

                \add_filter( 'cron_schedules', [ __CLASS__, 'cronSchedules' ], 99999, 1 );

                \add_action( 'WpieApp/Schedule/Start', [ __CLASS__, 'startSchedule' ], 10, 1 );
        }

        
        public static function cronSchedules( $schedules = [] ) {

                return array_merge( self::getSchedules(), $schedules );
        }

        
        public static function getSchedules() {

                return [
                        'wpie_2_min'      => [
                                'interval' => 2 * MINUTE_IN_SECONDS,
                                'display'  => __( 'Every 2 Minutes', 'wp-import-export' ),
                        ],
                        'wpie_10_min'     => [
                                'interval' => 10 * MINUTE_IN_SECONDS,
                                'display'  => __( 'Every 10 Minutes', 'wp-import-export' ),
                        ],
                        'wpie_30_min'     => [
                                'interval' => 30 * MINUTE_IN_SECONDS,
                                'display'  => __( 'Every 30 Minutes', 'wp-import-export' ),
                        ],
                        'wpie_hourly'     => [
                                'interval' => HOUR_IN_SECONDS,
                                'display'  => __( 'Once Hourly', 'wp-import-export' ),
                        ],
                        'wpie_twicedaily' => [
                                'interval' => 12 * HOUR_IN_SECONDS,
                                'display'  => __( 'Twice Daily', 'wp-import-export' ),
                        ],
                        'wpie_daily'      => [
                                'interval' => DAY_IN_SECONDS,
                                'display'  => __( 'Once Daily', 'wp-import-export' ),
                        ],
                        'wpie_weekly'     => [
                                'interval' => WEEK_IN_SECONDS,
                                'display'  => __( 'Once Weekly', 'wp-import-export' ),
                        ],
                        'wpie_monthly'    => [
                                'interval' => MONTH_IN_SECONDS,
                                'display'  => __( 'Once Monthly', 'wp-import-export' ),
                        ],
                ];
        }

        
        public static function startSchedule( $id = 0 ) {

                if ( absint( $id ) < 1 ) {
                        return;
                }
                $process = DB::wpdb()->get_var( DB::wpdb()->prepare( "SELECT `process` FROM " . DB::getPluginTable() . " where `id` = %d AND `status` != 'paused'", $id ) );

                if ( !Helper::isNonEmptyStr( $process ) ) {
                        return;
                }

                $action = (!Cron::isActive() || self::isExistingRunning( $id )) ? 'skip' : 'new';

                Helper::setModule( $process );

                Extensions::loadModules();

                if ( $process === "export" ) {
                        return ExportSchedule::run( $id, $action );
                } elseif ( $process === "import" ) {
                        return ImportSchedule::run( $id, $action );
                }
        }

        
        private static function isExistingRunning( $id = 0 ) {

                $skipNew = Helper::getOption( 'schedule-overloading' );

                if ( 'no' === $skipNew ) {
                        return false;
                }

                $existingId = DB::wpdb()->get_var( DB::wpdb()->prepare( "SELECT `id` FROM " . DB::getPluginTable() . " where `process_type` = 'background' AND `status` NOT IN ( 'paused','completed', 'cancelled', 'failed', 'stopped' ) AND `parent` = %d ORDER BY `id` ASC LIMIT 0,1 ", $id ) );

                return \absint( $existingId ) > 0;
        }
}
